'''

The MIT License (MIT)

Copyright (c) 2016 WavyCloud

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

'''

def can_paginate(operation_name=None):
    """
    Check if an operation can be paginated.
    
    :type operation_name: string
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').

    """
    pass

def create_delivery_stream(DeliveryStreamName=None, S3DestinationConfiguration=None, ExtendedS3DestinationConfiguration=None, RedshiftDestinationConfiguration=None, ElasticsearchDestinationConfiguration=None):
    """
    Creates a delivery stream.
    By default, you can create up to 20 delivery streams per region.
    This is an asynchronous operation that immediately returns. The initial status of the delivery stream is CREATING . After the delivery stream is created, its status is ACTIVE and it now accepts data. Attempts to send data to a delivery stream that is not in the ACTIVE state cause an exception. To check the state of a delivery stream, use  DescribeDeliveryStream .
    A delivery stream is configured with a single destination: Amazon S3, Amazon Elasticsearch Service, or Amazon Redshift. You must specify only one of the following destination configuration parameters: ExtendedS3DestinationConfiguration , S3DestinationConfiguration , ElasticsearchDestinationConfiguration , or RedshiftDestinationConfiguration .
    When you specify S3DestinationConfiguration , you can also provide the following optional values: BufferingHints , EncryptionConfiguration , and CompressionFormat . By default, if no BufferingHints value is provided, Firehose buffers data up to 5 MB or for 5 minutes, whichever condition is satisfied first. Note that BufferingHints is a hint, so there are some cases where the service cannot adhere to these conditions strictly; for example, record boundaries are such that the size is a little over or under the configured buffering size. By default, no encryption is performed. We strongly recommend that you enable encryption to ensure secure data storage in Amazon S3.
    A few notes about Amazon Redshift as a destination:
    Firehose assumes the IAM role that is configured as part of the destination. The role should allow the Firehose principal to assume the role, and the role should have permissions that allows the service to deliver the data. For more information, see Amazon S3 Bucket Access in the Amazon Kinesis Firehose Developer Guide .
    See also: AWS API Documentation
    
    
    :example: response = client.create_delivery_stream(
        DeliveryStreamName='string',
        S3DestinationConfiguration={
            'RoleARN': 'string',
            'BucketARN': 'string',
            'Prefix': 'string',
            'BufferingHints': {
                'SizeInMBs': 123,
                'IntervalInSeconds': 123
            },
            'CompressionFormat': 'UNCOMPRESSED'|'GZIP'|'ZIP'|'Snappy',
            'EncryptionConfiguration': {
                'NoEncryptionConfig': 'NoEncryption',
                'KMSEncryptionConfig': {
                    'AWSKMSKeyARN': 'string'
                }
            },
            'CloudWatchLoggingOptions': {
                'Enabled': True|False,
                'LogGroupName': 'string',
                'LogStreamName': 'string'
            }
        },
        ExtendedS3DestinationConfiguration={
            'RoleARN': 'string',
            'BucketARN': 'string',
            'Prefix': 'string',
            'BufferingHints': {
                'SizeInMBs': 123,
                'IntervalInSeconds': 123
            },
            'CompressionFormat': 'UNCOMPRESSED'|'GZIP'|'ZIP'|'Snappy',
            'EncryptionConfiguration': {
                'NoEncryptionConfig': 'NoEncryption',
                'KMSEncryptionConfig': {
                    'AWSKMSKeyARN': 'string'
                }
            },
            'CloudWatchLoggingOptions': {
                'Enabled': True|False,
                'LogGroupName': 'string',
                'LogStreamName': 'string'
            },
            'ProcessingConfiguration': {
                'Enabled': True|False,
                'Processors': [
                    {
                        'Type': 'Lambda',
                        'Parameters': [
                            {
                                'ParameterName': 'LambdaArn'|'NumberOfRetries',
                                'ParameterValue': 'string'
                            },
                        ]
                    },
                ]
            },
            'S3BackupMode': 'Disabled'|'Enabled',
            'S3BackupConfiguration': {
                'RoleARN': 'string',
                'BucketARN': 'string',
                'Prefix': 'string',
                'BufferingHints': {
                    'SizeInMBs': 123,
                    'IntervalInSeconds': 123
                },
                'CompressionFormat': 'UNCOMPRESSED'|'GZIP'|'ZIP'|'Snappy',
                'EncryptionConfiguration': {
                    'NoEncryptionConfig': 'NoEncryption',
                    'KMSEncryptionConfig': {
                        'AWSKMSKeyARN': 'string'
                    }
                },
                'CloudWatchLoggingOptions': {
                    'Enabled': True|False,
                    'LogGroupName': 'string',
                    'LogStreamName': 'string'
                }
            }
        },
        RedshiftDestinationConfiguration={
            'RoleARN': 'string',
            'ClusterJDBCURL': 'string',
            'CopyCommand': {
                'DataTableName': 'string',
                'DataTableColumns': 'string',
                'CopyOptions': 'string'
            },
            'Username': 'string',
            'Password': 'string',
            'RetryOptions': {
                'DurationInSeconds': 123
            },
            'S3Configuration': {
                'RoleARN': 'string',
                'BucketARN': 'string',
                'Prefix': 'string',
                'BufferingHints': {
                    'SizeInMBs': 123,
                    'IntervalInSeconds': 123
                },
                'CompressionFormat': 'UNCOMPRESSED'|'GZIP'|'ZIP'|'Snappy',
                'EncryptionConfiguration': {
                    'NoEncryptionConfig': 'NoEncryption',
                    'KMSEncryptionConfig': {
                        'AWSKMSKeyARN': 'string'
                    }
                },
                'CloudWatchLoggingOptions': {
                    'Enabled': True|False,
                    'LogGroupName': 'string',
                    'LogStreamName': 'string'
                }
            },
            'ProcessingConfiguration': {
                'Enabled': True|False,
                'Processors': [
                    {
                        'Type': 'Lambda',
                        'Parameters': [
                            {
                                'ParameterName': 'LambdaArn'|'NumberOfRetries',
                                'ParameterValue': 'string'
                            },
                        ]
                    },
                ]
            },
            'S3BackupMode': 'Disabled'|'Enabled',
            'S3BackupConfiguration': {
                'RoleARN': 'string',
                'BucketARN': 'string',
                'Prefix': 'string',
                'BufferingHints': {
                    'SizeInMBs': 123,
                    'IntervalInSeconds': 123
                },
                'CompressionFormat': 'UNCOMPRESSED'|'GZIP'|'ZIP'|'Snappy',
                'EncryptionConfiguration': {
                    'NoEncryptionConfig': 'NoEncryption',
                    'KMSEncryptionConfig': {
                        'AWSKMSKeyARN': 'string'
                    }
                },
                'CloudWatchLoggingOptions': {
                    'Enabled': True|False,
                    'LogGroupName': 'string',
                    'LogStreamName': 'string'
                }
            },
            'CloudWatchLoggingOptions': {
                'Enabled': True|False,
                'LogGroupName': 'string',
                'LogStreamName': 'string'
            }
        },
        ElasticsearchDestinationConfiguration={
            'RoleARN': 'string',
            'DomainARN': 'string',
            'IndexName': 'string',
            'TypeName': 'string',
            'IndexRotationPeriod': 'NoRotation'|'OneHour'|'OneDay'|'OneWeek'|'OneMonth',
            'BufferingHints': {
                'IntervalInSeconds': 123,
                'SizeInMBs': 123
            },
            'RetryOptions': {
                'DurationInSeconds': 123
            },
            'S3BackupMode': 'FailedDocumentsOnly'|'AllDocuments',
            'S3Configuration': {
                'RoleARN': 'string',
                'BucketARN': 'string',
                'Prefix': 'string',
                'BufferingHints': {
                    'SizeInMBs': 123,
                    'IntervalInSeconds': 123
                },
                'CompressionFormat': 'UNCOMPRESSED'|'GZIP'|'ZIP'|'Snappy',
                'EncryptionConfiguration': {
                    'NoEncryptionConfig': 'NoEncryption',
                    'KMSEncryptionConfig': {
                        'AWSKMSKeyARN': 'string'
                    }
                },
                'CloudWatchLoggingOptions': {
                    'Enabled': True|False,
                    'LogGroupName': 'string',
                    'LogStreamName': 'string'
                }
            },
            'ProcessingConfiguration': {
                'Enabled': True|False,
                'Processors': [
                    {
                        'Type': 'Lambda',
                        'Parameters': [
                            {
                                'ParameterName': 'LambdaArn'|'NumberOfRetries',
                                'ParameterValue': 'string'
                            },
                        ]
                    },
                ]
            },
            'CloudWatchLoggingOptions': {
                'Enabled': True|False,
                'LogGroupName': 'string',
                'LogStreamName': 'string'
            }
        }
    )
    
    
    :type DeliveryStreamName: string
    :param DeliveryStreamName: [REQUIRED]
            The name of the delivery stream. This name must be unique per AWS account in the same region. You can have multiple delivery streams with the same name if they are in different accounts or different regions.
            

    :type S3DestinationConfiguration: dict
    :param S3DestinationConfiguration: [Deprecated] The destination in Amazon S3. You can specify only one destination.
            RoleARN (string) -- [REQUIRED]The ARN of the AWS credentials.
            BucketARN (string) -- [REQUIRED]The ARN of the S3 bucket.
            Prefix (string) --The 'YYYY/MM/DD/HH' time format prefix is automatically used for delivered S3 files. You can specify an extra prefix to be added in front of the time format prefix. Note that if the prefix ends with a slash, it appears as a folder in the S3 bucket. For more information, see Amazon S3 Object Name Format in the Amazon Kinesis Firehose Developer Guide .
            BufferingHints (dict) --The buffering option. If no value is specified, BufferingHints object default values are used.
            SizeInMBs (integer) --Buffer incoming data to the specified size, in MBs, before delivering it to the destination. The default value is 5.
            We recommend setting this parameter to a value greater than the amount of data you typically ingest into the delivery stream in 10 seconds. For example, if you typically ingest data at 1 MB/sec, the value should be 10 MB or higher.
            IntervalInSeconds (integer) --Buffer incoming data for the specified period of time, in seconds, before delivering it to the destination. The default value is 300.
            CompressionFormat (string) --The compression format. If no value is specified, the default is UNCOMPRESSED .
            The compression formats SNAPPY or ZIP cannot be specified for Amazon Redshift destinations because they are not supported by the Amazon Redshift COPY operation that reads from the S3 bucket.
            EncryptionConfiguration (dict) --The encryption configuration. If no value is specified, the default is no encryption.
            NoEncryptionConfig (string) --Specifically override existing encryption information to ensure no encryption is used.
            KMSEncryptionConfig (dict) --The encryption key.
            AWSKMSKeyARN (string) -- [REQUIRED]The ARN of the encryption key. Must belong to the same region as the destination Amazon S3 bucket.
            
            CloudWatchLoggingOptions (dict) --The CloudWatch logging options for your delivery stream.
            Enabled (boolean) --Enables or disables CloudWatch logging.
            LogGroupName (string) --The CloudWatch group name for logging. This value is required if CloudWatch logging is enabled.
            LogStreamName (string) --The CloudWatch log stream name for logging. This value is required if CloudWatch logging is enabled.
            
            

    :type ExtendedS3DestinationConfiguration: dict
    :param ExtendedS3DestinationConfiguration: The destination in Amazon S3. You can specify only one destination.
            RoleARN (string) -- [REQUIRED]The ARN of the AWS credentials.
            BucketARN (string) -- [REQUIRED]The ARN of the S3 bucket.
            Prefix (string) --The 'YYYY/MM/DD/HH' time format prefix is automatically used for delivered S3 files. You can specify an extra prefix to be added in front of the time format prefix. Note that if the prefix ends with a slash, it appears as a folder in the S3 bucket. For more information, see Amazon S3 Object Name Format in the Amazon Kinesis Firehose Developer Guide .
            BufferingHints (dict) --The buffering option.
            SizeInMBs (integer) --Buffer incoming data to the specified size, in MBs, before delivering it to the destination. The default value is 5.
            We recommend setting this parameter to a value greater than the amount of data you typically ingest into the delivery stream in 10 seconds. For example, if you typically ingest data at 1 MB/sec, the value should be 10 MB or higher.
            IntervalInSeconds (integer) --Buffer incoming data for the specified period of time, in seconds, before delivering it to the destination. The default value is 300.
            CompressionFormat (string) --The compression format. If no value is specified, the default is UNCOMPRESSED.
            EncryptionConfiguration (dict) --The encryption configuration. If no value is specified, the default is no encryption.
            NoEncryptionConfig (string) --Specifically override existing encryption information to ensure no encryption is used.
            KMSEncryptionConfig (dict) --The encryption key.
            AWSKMSKeyARN (string) -- [REQUIRED]The ARN of the encryption key. Must belong to the same region as the destination Amazon S3 bucket.
            
            CloudWatchLoggingOptions (dict) --The CloudWatch logging options for your delivery stream.
            Enabled (boolean) --Enables or disables CloudWatch logging.
            LogGroupName (string) --The CloudWatch group name for logging. This value is required if CloudWatch logging is enabled.
            LogStreamName (string) --The CloudWatch log stream name for logging. This value is required if CloudWatch logging is enabled.
            ProcessingConfiguration (dict) --The data processing configuration.
            Enabled (boolean) --Enables or disables data processing.
            Processors (list) --The data processors.
            (dict) --Describes a data processor.
            Type (string) -- [REQUIRED]The type of processor.
            Parameters (list) --The processor parameters.
            (dict) --Describes the processor parameter.
            ParameterName (string) -- [REQUIRED]The name of the parameter.
            ParameterValue (string) -- [REQUIRED]The parameter value.
            
            
            S3BackupMode (string) --The Amazon S3 backup mode.
            S3BackupConfiguration (dict) --The configuration for backup in Amazon S3.
            RoleARN (string) -- [REQUIRED]The ARN of the AWS credentials.
            BucketARN (string) -- [REQUIRED]The ARN of the S3 bucket.
            Prefix (string) --The 'YYYY/MM/DD/HH' time format prefix is automatically used for delivered S3 files. You can specify an extra prefix to be added in front of the time format prefix. Note that if the prefix ends with a slash, it appears as a folder in the S3 bucket. For more information, see Amazon S3 Object Name Format in the Amazon Kinesis Firehose Developer Guide .
            BufferingHints (dict) --The buffering option. If no value is specified, BufferingHints object default values are used.
            SizeInMBs (integer) --Buffer incoming data to the specified size, in MBs, before delivering it to the destination. The default value is 5.
            We recommend setting this parameter to a value greater than the amount of data you typically ingest into the delivery stream in 10 seconds. For example, if you typically ingest data at 1 MB/sec, the value should be 10 MB or higher.
            IntervalInSeconds (integer) --Buffer incoming data for the specified period of time, in seconds, before delivering it to the destination. The default value is 300.
            CompressionFormat (string) --The compression format. If no value is specified, the default is UNCOMPRESSED .
            The compression formats SNAPPY or ZIP cannot be specified for Amazon Redshift destinations because they are not supported by the Amazon Redshift COPY operation that reads from the S3 bucket.
            EncryptionConfiguration (dict) --The encryption configuration. If no value is specified, the default is no encryption.
            NoEncryptionConfig (string) --Specifically override existing encryption information to ensure no encryption is used.
            KMSEncryptionConfig (dict) --The encryption key.
            AWSKMSKeyARN (string) -- [REQUIRED]The ARN of the encryption key. Must belong to the same region as the destination Amazon S3 bucket.
            
            CloudWatchLoggingOptions (dict) --The CloudWatch logging options for your delivery stream.
            Enabled (boolean) --Enables or disables CloudWatch logging.
            LogGroupName (string) --The CloudWatch group name for logging. This value is required if CloudWatch logging is enabled.
            LogStreamName (string) --The CloudWatch log stream name for logging. This value is required if CloudWatch logging is enabled.
            
            

    :type RedshiftDestinationConfiguration: dict
    :param RedshiftDestinationConfiguration: The destination in Amazon Redshift. You can specify only one destination.
            RoleARN (string) -- [REQUIRED]The ARN of the AWS credentials.
            ClusterJDBCURL (string) -- [REQUIRED]The database connection string.
            CopyCommand (dict) -- [REQUIRED]The COPY command.
            DataTableName (string) -- [REQUIRED]The name of the target table. The table must already exist in the database.
            DataTableColumns (string) --A comma-separated list of column names.
            CopyOptions (string) --Optional parameters to use with the Amazon Redshift COPY command. For more information, see the 'Optional Parameters' section of Amazon Redshift COPY command . Some possible examples that would apply to Firehose are as follows:
            delimiter '\t' lzop; - fields are delimited with 't' (TAB character) and compressed using lzop.delimiter '| - fields are delimited with '|' (this is the default delimiter).
            delimiter '|' escape - the delimiter should be escaped.
            fixedwidth 'venueid:3,venuename:25,venuecity:12,venuestate:2,venueseats:6' - fields are fixed width in the source, with each width specified after every column in the table.
            JSON 's3://mybucket/jsonpaths.txt' - data is in JSON format, and the path specified is the format of the data.
            For more examples, see Amazon Redshift COPY command examples .
            Username (string) -- [REQUIRED]The name of the user.
            Password (string) -- [REQUIRED]The user password.
            RetryOptions (dict) --The retry behavior in the event that Firehose is unable to deliver documents to Amazon Redshift. Default value is 3600 (60 minutes).
            DurationInSeconds (integer) --The length of time during which Firehose retries delivery after a failure, starting from the initial request and including the first attempt. The default value is 3600 seconds (60 minutes). Firehose does not retry if the value of DurationInSeconds is 0 (zero) or if the first delivery attempt takes longer than the current value.
            S3Configuration (dict) -- [REQUIRED]The configuration for the intermediate Amazon S3 location from which Amazon Redshift obtains data. Restrictions are described in the topic for CreateDeliveryStream .
            The compression formats SNAPPY or ZIP cannot be specified in RedshiftDestinationConfiguration.S3Configuration because the Amazon Redshift COPY operation that reads from the S3 bucket doesn't support these compression formats.
            RoleARN (string) -- [REQUIRED]The ARN of the AWS credentials.
            BucketARN (string) -- [REQUIRED]The ARN of the S3 bucket.
            Prefix (string) --The 'YYYY/MM/DD/HH' time format prefix is automatically used for delivered S3 files. You can specify an extra prefix to be added in front of the time format prefix. Note that if the prefix ends with a slash, it appears as a folder in the S3 bucket. For more information, see Amazon S3 Object Name Format in the Amazon Kinesis Firehose Developer Guide .
            BufferingHints (dict) --The buffering option. If no value is specified, BufferingHints object default values are used.
            SizeInMBs (integer) --Buffer incoming data to the specified size, in MBs, before delivering it to the destination. The default value is 5.
            We recommend setting this parameter to a value greater than the amount of data you typically ingest into the delivery stream in 10 seconds. For example, if you typically ingest data at 1 MB/sec, the value should be 10 MB or higher.
            IntervalInSeconds (integer) --Buffer incoming data for the specified period of time, in seconds, before delivering it to the destination. The default value is 300.
            CompressionFormat (string) --The compression format. If no value is specified, the default is UNCOMPRESSED .
            The compression formats SNAPPY or ZIP cannot be specified for Amazon Redshift destinations because they are not supported by the Amazon Redshift COPY operation that reads from the S3 bucket.
            EncryptionConfiguration (dict) --The encryption configuration. If no value is specified, the default is no encryption.
            NoEncryptionConfig (string) --Specifically override existing encryption information to ensure no encryption is used.
            KMSEncryptionConfig (dict) --The encryption key.
            AWSKMSKeyARN (string) -- [REQUIRED]The ARN of the encryption key. Must belong to the same region as the destination Amazon S3 bucket.
            
            CloudWatchLoggingOptions (dict) --The CloudWatch logging options for your delivery stream.
            Enabled (boolean) --Enables or disables CloudWatch logging.
            LogGroupName (string) --The CloudWatch group name for logging. This value is required if CloudWatch logging is enabled.
            LogStreamName (string) --The CloudWatch log stream name for logging. This value is required if CloudWatch logging is enabled.
            
            ProcessingConfiguration (dict) --The data processing configuration.
            Enabled (boolean) --Enables or disables data processing.
            Processors (list) --The data processors.
            (dict) --Describes a data processor.
            Type (string) -- [REQUIRED]The type of processor.
            Parameters (list) --The processor parameters.
            (dict) --Describes the processor parameter.
            ParameterName (string) -- [REQUIRED]The name of the parameter.
            ParameterValue (string) -- [REQUIRED]The parameter value.
            
            
            S3BackupMode (string) --The Amazon S3 backup mode.
            S3BackupConfiguration (dict) --The configuration for backup in Amazon S3.
            RoleARN (string) -- [REQUIRED]The ARN of the AWS credentials.
            BucketARN (string) -- [REQUIRED]The ARN of the S3 bucket.
            Prefix (string) --The 'YYYY/MM/DD/HH' time format prefix is automatically used for delivered S3 files. You can specify an extra prefix to be added in front of the time format prefix. Note that if the prefix ends with a slash, it appears as a folder in the S3 bucket. For more information, see Amazon S3 Object Name Format in the Amazon Kinesis Firehose Developer Guide .
            BufferingHints (dict) --The buffering option. If no value is specified, BufferingHints object default values are used.
            SizeInMBs (integer) --Buffer incoming data to the specified size, in MBs, before delivering it to the destination. The default value is 5.
            We recommend setting this parameter to a value greater than the amount of data you typically ingest into the delivery stream in 10 seconds. For example, if you typically ingest data at 1 MB/sec, the value should be 10 MB or higher.
            IntervalInSeconds (integer) --Buffer incoming data for the specified period of time, in seconds, before delivering it to the destination. The default value is 300.
            CompressionFormat (string) --The compression format. If no value is specified, the default is UNCOMPRESSED .
            The compression formats SNAPPY or ZIP cannot be specified for Amazon Redshift destinations because they are not supported by the Amazon Redshift COPY operation that reads from the S3 bucket.
            EncryptionConfiguration (dict) --The encryption configuration. If no value is specified, the default is no encryption.
            NoEncryptionConfig (string) --Specifically override existing encryption information to ensure no encryption is used.
            KMSEncryptionConfig (dict) --The encryption key.
            AWSKMSKeyARN (string) -- [REQUIRED]The ARN of the encryption key. Must belong to the same region as the destination Amazon S3 bucket.
            
            CloudWatchLoggingOptions (dict) --The CloudWatch logging options for your delivery stream.
            Enabled (boolean) --Enables or disables CloudWatch logging.
            LogGroupName (string) --The CloudWatch group name for logging. This value is required if CloudWatch logging is enabled.
            LogStreamName (string) --The CloudWatch log stream name for logging. This value is required if CloudWatch logging is enabled.
            
            CloudWatchLoggingOptions (dict) --The CloudWatch logging options for your delivery stream.
            Enabled (boolean) --Enables or disables CloudWatch logging.
            LogGroupName (string) --The CloudWatch group name for logging. This value is required if CloudWatch logging is enabled.
            LogStreamName (string) --The CloudWatch log stream name for logging. This value is required if CloudWatch logging is enabled.
            
            

    :type ElasticsearchDestinationConfiguration: dict
    :param ElasticsearchDestinationConfiguration: The destination in Amazon ES. You can specify only one destination.
            RoleARN (string) -- [REQUIRED]The ARN of the IAM role to be assumed by Firehose for calling the Amazon ES Configuration API and for indexing documents. For more information, see Amazon S3 Bucket Access .
            DomainARN (string) -- [REQUIRED]The ARN of the Amazon ES domain. The IAM role must have permissions for DescribeElasticsearchDomain , DescribeElasticsearchDomains , and DescribeElasticsearchDomainConfig after assuming the role specified in RoleARN .
            IndexName (string) -- [REQUIRED]The Elasticsearch index name.
            TypeName (string) -- [REQUIRED]The Elasticsearch type name.
            IndexRotationPeriod (string) --The Elasticsearch index rotation period. Index rotation appends a timestamp to the IndexName to facilitate expiration of old data. For more information, see Index Rotation for Amazon Elasticsearch Service Destination . The default value is OneDay .
            BufferingHints (dict) --The buffering options. If no value is specified, the default values for ElasticsearchBufferingHints are used.
            IntervalInSeconds (integer) --Buffer incoming data for the specified period of time, in seconds, before delivering it to the destination. The default value is 300 (5 minutes).
            SizeInMBs (integer) --Buffer incoming data to the specified size, in MBs, before delivering it to the destination. The default value is 5.
            We recommend setting this parameter to a value greater than the amount of data you typically ingest into the delivery stream in 10 seconds. For example, if you typically ingest data at 1 MB/sec, the value should be 10 MB or higher.
            RetryOptions (dict) --The retry behavior in the event that Firehose is unable to deliver documents to Amazon ES. The default value is 300 (5 minutes).
            DurationInSeconds (integer) --After an initial failure to deliver to Amazon ES, the total amount of time during which Firehose re-attempts delivery (including the first attempt). After this time has elapsed, the failed documents are written to Amazon S3. Default value is 300 seconds (5 minutes). A value of 0 (zero) results in no retries.
            S3BackupMode (string) --Defines how documents should be delivered to Amazon S3. When set to FailedDocumentsOnly, Firehose writes any documents that could not be indexed to the configured Amazon S3 destination, with elasticsearch-failed/ appended to the key prefix. When set to AllDocuments, Firehose delivers all incoming records to Amazon S3, and also writes failed documents with elasticsearch-failed/ appended to the prefix. For more information, see Amazon S3 Backup for Amazon Elasticsearch Service Destination . Default value is FailedDocumentsOnly.
            S3Configuration (dict) -- [REQUIRED]The configuration for the intermediate Amazon S3 location from which Amazon ES obtains data.
            RoleARN (string) -- [REQUIRED]The ARN of the AWS credentials.
            BucketARN (string) -- [REQUIRED]The ARN of the S3 bucket.
            Prefix (string) --The 'YYYY/MM/DD/HH' time format prefix is automatically used for delivered S3 files. You can specify an extra prefix to be added in front of the time format prefix. Note that if the prefix ends with a slash, it appears as a folder in the S3 bucket. For more information, see Amazon S3 Object Name Format in the Amazon Kinesis Firehose Developer Guide .
            BufferingHints (dict) --The buffering option. If no value is specified, BufferingHints object default values are used.
            SizeInMBs (integer) --Buffer incoming data to the specified size, in MBs, before delivering it to the destination. The default value is 5.
            We recommend setting this parameter to a value greater than the amount of data you typically ingest into the delivery stream in 10 seconds. For example, if you typically ingest data at 1 MB/sec, the value should be 10 MB or higher.
            IntervalInSeconds (integer) --Buffer incoming data for the specified period of time, in seconds, before delivering it to the destination. The default value is 300.
            CompressionFormat (string) --The compression format. If no value is specified, the default is UNCOMPRESSED .
            The compression formats SNAPPY or ZIP cannot be specified for Amazon Redshift destinations because they are not supported by the Amazon Redshift COPY operation that reads from the S3 bucket.
            EncryptionConfiguration (dict) --The encryption configuration. If no value is specified, the default is no encryption.
            NoEncryptionConfig (string) --Specifically override existing encryption information to ensure no encryption is used.
            KMSEncryptionConfig (dict) --The encryption key.
            AWSKMSKeyARN (string) -- [REQUIRED]The ARN of the encryption key. Must belong to the same region as the destination Amazon S3 bucket.
            
            CloudWatchLoggingOptions (dict) --The CloudWatch logging options for your delivery stream.
            Enabled (boolean) --Enables or disables CloudWatch logging.
            LogGroupName (string) --The CloudWatch group name for logging. This value is required if CloudWatch logging is enabled.
            LogStreamName (string) --The CloudWatch log stream name for logging. This value is required if CloudWatch logging is enabled.
            
            ProcessingConfiguration (dict) --The data processing configuration.
            Enabled (boolean) --Enables or disables data processing.
            Processors (list) --The data processors.
            (dict) --Describes a data processor.
            Type (string) -- [REQUIRED]The type of processor.
            Parameters (list) --The processor parameters.
            (dict) --Describes the processor parameter.
            ParameterName (string) -- [REQUIRED]The name of the parameter.
            ParameterValue (string) -- [REQUIRED]The parameter value.
            
            
            CloudWatchLoggingOptions (dict) --The CloudWatch logging options for your delivery stream.
            Enabled (boolean) --Enables or disables CloudWatch logging.
            LogGroupName (string) --The CloudWatch group name for logging. This value is required if CloudWatch logging is enabled.
            LogStreamName (string) --The CloudWatch log stream name for logging. This value is required if CloudWatch logging is enabled.
            
            

    :rtype: dict
    :return: {
        'DeliveryStreamARN': 'string'
    }
    
    
    :returns: 
    DeliveryStreamName (string) -- [REQUIRED]
    The name of the delivery stream. This name must be unique per AWS account in the same region. You can have multiple delivery streams with the same name if they are in different accounts or different regions.
    
    S3DestinationConfiguration (dict) -- [Deprecated] The destination in Amazon S3. You can specify only one destination.
    
    RoleARN (string) -- [REQUIRED]The ARN of the AWS credentials.
    
    BucketARN (string) -- [REQUIRED]The ARN of the S3 bucket.
    
    Prefix (string) --The "YYYY/MM/DD/HH" time format prefix is automatically used for delivered S3 files. You can specify an extra prefix to be added in front of the time format prefix. Note that if the prefix ends with a slash, it appears as a folder in the S3 bucket. For more information, see Amazon S3 Object Name Format in the Amazon Kinesis Firehose Developer Guide .
    
    BufferingHints (dict) --The buffering option. If no value is specified, BufferingHints object default values are used.
    
    SizeInMBs (integer) --Buffer incoming data to the specified size, in MBs, before delivering it to the destination. The default value is 5.
    We recommend setting this parameter to a value greater than the amount of data you typically ingest into the delivery stream in 10 seconds. For example, if you typically ingest data at 1 MB/sec, the value should be 10 MB or higher.
    
    IntervalInSeconds (integer) --Buffer incoming data for the specified period of time, in seconds, before delivering it to the destination. The default value is 300.
    
    
    
    CompressionFormat (string) --The compression format. If no value is specified, the default is UNCOMPRESSED .
    The compression formats SNAPPY or ZIP cannot be specified for Amazon Redshift destinations because they are not supported by the Amazon Redshift COPY operation that reads from the S3 bucket.
    
    EncryptionConfiguration (dict) --The encryption configuration. If no value is specified, the default is no encryption.
    
    NoEncryptionConfig (string) --Specifically override existing encryption information to ensure no encryption is used.
    
    KMSEncryptionConfig (dict) --The encryption key.
    
    AWSKMSKeyARN (string) -- [REQUIRED]The ARN of the encryption key. Must belong to the same region as the destination Amazon S3 bucket.
    
    
    
    
    
    CloudWatchLoggingOptions (dict) --The CloudWatch logging options for your delivery stream.
    
    Enabled (boolean) --Enables or disables CloudWatch logging.
    
    LogGroupName (string) --The CloudWatch group name for logging. This value is required if CloudWatch logging is enabled.
    
    LogStreamName (string) --The CloudWatch log stream name for logging. This value is required if CloudWatch logging is enabled.
    
    
    
    
    
    ExtendedS3DestinationConfiguration (dict) -- The destination in Amazon S3. You can specify only one destination.
    
    RoleARN (string) -- [REQUIRED]The ARN of the AWS credentials.
    
    BucketARN (string) -- [REQUIRED]The ARN of the S3 bucket.
    
    Prefix (string) --The "YYYY/MM/DD/HH" time format prefix is automatically used for delivered S3 files. You can specify an extra prefix to be added in front of the time format prefix. Note that if the prefix ends with a slash, it appears as a folder in the S3 bucket. For more information, see Amazon S3 Object Name Format in the Amazon Kinesis Firehose Developer Guide .
    
    BufferingHints (dict) --The buffering option.
    
    SizeInMBs (integer) --Buffer incoming data to the specified size, in MBs, before delivering it to the destination. The default value is 5.
    We recommend setting this parameter to a value greater than the amount of data you typically ingest into the delivery stream in 10 seconds. For example, if you typically ingest data at 1 MB/sec, the value should be 10 MB or higher.
    
    IntervalInSeconds (integer) --Buffer incoming data for the specified period of time, in seconds, before delivering it to the destination. The default value is 300.
    
    
    
    CompressionFormat (string) --The compression format. If no value is specified, the default is UNCOMPRESSED.
    
    EncryptionConfiguration (dict) --The encryption configuration. If no value is specified, the default is no encryption.
    
    NoEncryptionConfig (string) --Specifically override existing encryption information to ensure no encryption is used.
    
    KMSEncryptionConfig (dict) --The encryption key.
    
    AWSKMSKeyARN (string) -- [REQUIRED]The ARN of the encryption key. Must belong to the same region as the destination Amazon S3 bucket.
    
    
    
    
    
    CloudWatchLoggingOptions (dict) --The CloudWatch logging options for your delivery stream.
    
    Enabled (boolean) --Enables or disables CloudWatch logging.
    
    LogGroupName (string) --The CloudWatch group name for logging. This value is required if CloudWatch logging is enabled.
    
    LogStreamName (string) --The CloudWatch log stream name for logging. This value is required if CloudWatch logging is enabled.
    
    
    
    ProcessingConfiguration (dict) --The data processing configuration.
    
    Enabled (boolean) --Enables or disables data processing.
    
    Processors (list) --The data processors.
    
    (dict) --Describes a data processor.
    
    Type (string) -- [REQUIRED]The type of processor.
    
    Parameters (list) --The processor parameters.
    
    (dict) --Describes the processor parameter.
    
    ParameterName (string) -- [REQUIRED]The name of the parameter.
    
    ParameterValue (string) -- [REQUIRED]The parameter value.
    
    
    
    
    
    
    
    
    
    
    
    S3BackupMode (string) --The Amazon S3 backup mode.
    
    S3BackupConfiguration (dict) --The configuration for backup in Amazon S3.
    
    RoleARN (string) -- [REQUIRED]The ARN of the AWS credentials.
    
    BucketARN (string) -- [REQUIRED]The ARN of the S3 bucket.
    
    Prefix (string) --The "YYYY/MM/DD/HH" time format prefix is automatically used for delivered S3 files. You can specify an extra prefix to be added in front of the time format prefix. Note that if the prefix ends with a slash, it appears as a folder in the S3 bucket. For more information, see Amazon S3 Object Name Format in the Amazon Kinesis Firehose Developer Guide .
    
    BufferingHints (dict) --The buffering option. If no value is specified, BufferingHints object default values are used.
    
    SizeInMBs (integer) --Buffer incoming data to the specified size, in MBs, before delivering it to the destination. The default value is 5.
    We recommend setting this parameter to a value greater than the amount of data you typically ingest into the delivery stream in 10 seconds. For example, if you typically ingest data at 1 MB/sec, the value should be 10 MB or higher.
    
    IntervalInSeconds (integer) --Buffer incoming data for the specified period of time, in seconds, before delivering it to the destination. The default value is 300.
    
    
    
    CompressionFormat (string) --The compression format. If no value is specified, the default is UNCOMPRESSED .
    The compression formats SNAPPY or ZIP cannot be specified for Amazon Redshift destinations because they are not supported by the Amazon Redshift COPY operation that reads from the S3 bucket.
    
    EncryptionConfiguration (dict) --The encryption configuration. If no value is specified, the default is no encryption.
    
    NoEncryptionConfig (string) --Specifically override existing encryption information to ensure no encryption is used.
    
    KMSEncryptionConfig (dict) --The encryption key.
    
    AWSKMSKeyARN (string) -- [REQUIRED]The ARN of the encryption key. Must belong to the same region as the destination Amazon S3 bucket.
    
    
    
    
    
    CloudWatchLoggingOptions (dict) --The CloudWatch logging options for your delivery stream.
    
    Enabled (boolean) --Enables or disables CloudWatch logging.
    
    LogGroupName (string) --The CloudWatch group name for logging. This value is required if CloudWatch logging is enabled.
    
    LogStreamName (string) --The CloudWatch log stream name for logging. This value is required if CloudWatch logging is enabled.
    
    
    
    
    
    
    
    RedshiftDestinationConfiguration (dict) -- The destination in Amazon Redshift. You can specify only one destination.
    
    RoleARN (string) -- [REQUIRED]The ARN of the AWS credentials.
    
    ClusterJDBCURL (string) -- [REQUIRED]The database connection string.
    
    CopyCommand (dict) -- [REQUIRED]The COPY command.
    
    DataTableName (string) -- [REQUIRED]The name of the target table. The table must already exist in the database.
    
    DataTableColumns (string) --A comma-separated list of column names.
    
    CopyOptions (string) --Optional parameters to use with the Amazon Redshift COPY command. For more information, see the "Optional Parameters" section of Amazon Redshift COPY command . Some possible examples that would apply to Firehose are as follows:
    
    delimiter '\t' lzop; - fields are delimited with "t" (TAB character) and compressed using lzop.delimiter '| - fields are delimited with "|" (this is the default delimiter).
    delimiter '|' escape - the delimiter should be escaped.
    fixedwidth 'venueid:3,venuename:25,venuecity:12,venuestate:2,venueseats:6' - fields are fixed width in the source, with each width specified after every column in the table.
    JSON 's3://mybucket/jsonpaths.txt' - data is in JSON format, and the path specified is the format of the data.
    
    For more examples, see Amazon Redshift COPY command examples .
    
    
    
    Username (string) -- [REQUIRED]The name of the user.
    
    Password (string) -- [REQUIRED]The user password.
    
    RetryOptions (dict) --The retry behavior in the event that Firehose is unable to deliver documents to Amazon Redshift. Default value is 3600 (60 minutes).
    
    DurationInSeconds (integer) --The length of time during which Firehose retries delivery after a failure, starting from the initial request and including the first attempt. The default value is 3600 seconds (60 minutes). Firehose does not retry if the value of DurationInSeconds is 0 (zero) or if the first delivery attempt takes longer than the current value.
    
    
    
    S3Configuration (dict) -- [REQUIRED]The configuration for the intermediate Amazon S3 location from which Amazon Redshift obtains data. Restrictions are described in the topic for  CreateDeliveryStream .
    The compression formats SNAPPY or ZIP cannot be specified in RedshiftDestinationConfiguration.S3Configuration because the Amazon Redshift COPY operation that reads from the S3 bucket doesn't support these compression formats.
    
    RoleARN (string) -- [REQUIRED]The ARN of the AWS credentials.
    
    BucketARN (string) -- [REQUIRED]The ARN of the S3 bucket.
    
    Prefix (string) --The "YYYY/MM/DD/HH" time format prefix is automatically used for delivered S3 files. You can specify an extra prefix to be added in front of the time format prefix. Note that if the prefix ends with a slash, it appears as a folder in the S3 bucket. For more information, see Amazon S3 Object Name Format in the Amazon Kinesis Firehose Developer Guide .
    
    BufferingHints (dict) --The buffering option. If no value is specified, BufferingHints object default values are used.
    
    SizeInMBs (integer) --Buffer incoming data to the specified size, in MBs, before delivering it to the destination. The default value is 5.
    We recommend setting this parameter to a value greater than the amount of data you typically ingest into the delivery stream in 10 seconds. For example, if you typically ingest data at 1 MB/sec, the value should be 10 MB or higher.
    
    IntervalInSeconds (integer) --Buffer incoming data for the specified period of time, in seconds, before delivering it to the destination. The default value is 300.
    
    
    
    CompressionFormat (string) --The compression format. If no value is specified, the default is UNCOMPRESSED .
    The compression formats SNAPPY or ZIP cannot be specified for Amazon Redshift destinations because they are not supported by the Amazon Redshift COPY operation that reads from the S3 bucket.
    
    EncryptionConfiguration (dict) --The encryption configuration. If no value is specified, the default is no encryption.
    
    NoEncryptionConfig (string) --Specifically override existing encryption information to ensure no encryption is used.
    
    KMSEncryptionConfig (dict) --The encryption key.
    
    AWSKMSKeyARN (string) -- [REQUIRED]The ARN of the encryption key. Must belong to the same region as the destination Amazon S3 bucket.
    
    
    
    
    
    CloudWatchLoggingOptions (dict) --The CloudWatch logging options for your delivery stream.
    
    Enabled (boolean) --Enables or disables CloudWatch logging.
    
    LogGroupName (string) --The CloudWatch group name for logging. This value is required if CloudWatch logging is enabled.
    
    LogStreamName (string) --The CloudWatch log stream name for logging. This value is required if CloudWatch logging is enabled.
    
    
    
    
    
    ProcessingConfiguration (dict) --The data processing configuration.
    
    Enabled (boolean) --Enables or disables data processing.
    
    Processors (list) --The data processors.
    
    (dict) --Describes a data processor.
    
    Type (string) -- [REQUIRED]The type of processor.
    
    Parameters (list) --The processor parameters.
    
    (dict) --Describes the processor parameter.
    
    ParameterName (string) -- [REQUIRED]The name of the parameter.
    
    ParameterValue (string) -- [REQUIRED]The parameter value.
    
    
    
    
    
    
    
    
    
    
    
    S3BackupMode (string) --The Amazon S3 backup mode.
    
    S3BackupConfiguration (dict) --The configuration for backup in Amazon S3.
    
    RoleARN (string) -- [REQUIRED]The ARN of the AWS credentials.
    
    BucketARN (string) -- [REQUIRED]The ARN of the S3 bucket.
    
    Prefix (string) --The "YYYY/MM/DD/HH" time format prefix is automatically used for delivered S3 files. You can specify an extra prefix to be added in front of the time format prefix. Note that if the prefix ends with a slash, it appears as a folder in the S3 bucket. For more information, see Amazon S3 Object Name Format in the Amazon Kinesis Firehose Developer Guide .
    
    BufferingHints (dict) --The buffering option. If no value is specified, BufferingHints object default values are used.
    
    SizeInMBs (integer) --Buffer incoming data to the specified size, in MBs, before delivering it to the destination. The default value is 5.
    We recommend setting this parameter to a value greater than the amount of data you typically ingest into the delivery stream in 10 seconds. For example, if you typically ingest data at 1 MB/sec, the value should be 10 MB or higher.
    
    IntervalInSeconds (integer) --Buffer incoming data for the specified period of time, in seconds, before delivering it to the destination. The default value is 300.
    
    
    
    CompressionFormat (string) --The compression format. If no value is specified, the default is UNCOMPRESSED .
    The compression formats SNAPPY or ZIP cannot be specified for Amazon Redshift destinations because they are not supported by the Amazon Redshift COPY operation that reads from the S3 bucket.
    
    EncryptionConfiguration (dict) --The encryption configuration. If no value is specified, the default is no encryption.
    
    NoEncryptionConfig (string) --Specifically override existing encryption information to ensure no encryption is used.
    
    KMSEncryptionConfig (dict) --The encryption key.
    
    AWSKMSKeyARN (string) -- [REQUIRED]The ARN of the encryption key. Must belong to the same region as the destination Amazon S3 bucket.
    
    
    
    
    
    CloudWatchLoggingOptions (dict) --The CloudWatch logging options for your delivery stream.
    
    Enabled (boolean) --Enables or disables CloudWatch logging.
    
    LogGroupName (string) --The CloudWatch group name for logging. This value is required if CloudWatch logging is enabled.
    
    LogStreamName (string) --The CloudWatch log stream name for logging. This value is required if CloudWatch logging is enabled.
    
    
    
    
    
    CloudWatchLoggingOptions (dict) --The CloudWatch logging options for your delivery stream.
    
    Enabled (boolean) --Enables or disables CloudWatch logging.
    
    LogGroupName (string) --The CloudWatch group name for logging. This value is required if CloudWatch logging is enabled.
    
    LogStreamName (string) --The CloudWatch log stream name for logging. This value is required if CloudWatch logging is enabled.
    
    
    
    
    
    ElasticsearchDestinationConfiguration (dict) -- The destination in Amazon ES. You can specify only one destination.
    
    RoleARN (string) -- [REQUIRED]The ARN of the IAM role to be assumed by Firehose for calling the Amazon ES Configuration API and for indexing documents. For more information, see Amazon S3 Bucket Access .
    
    DomainARN (string) -- [REQUIRED]The ARN of the Amazon ES domain. The IAM role must have permissions for DescribeElasticsearchDomain , DescribeElasticsearchDomains , and DescribeElasticsearchDomainConfig after assuming the role specified in RoleARN .
    
    IndexName (string) -- [REQUIRED]The Elasticsearch index name.
    
    TypeName (string) -- [REQUIRED]The Elasticsearch type name.
    
    IndexRotationPeriod (string) --The Elasticsearch index rotation period. Index rotation appends a timestamp to the IndexName to facilitate expiration of old data. For more information, see Index Rotation for Amazon Elasticsearch Service Destination . The default value is OneDay .
    
    BufferingHints (dict) --The buffering options. If no value is specified, the default values for ElasticsearchBufferingHints are used.
    
    IntervalInSeconds (integer) --Buffer incoming data for the specified period of time, in seconds, before delivering it to the destination. The default value is 300 (5 minutes).
    
    SizeInMBs (integer) --Buffer incoming data to the specified size, in MBs, before delivering it to the destination. The default value is 5.
    We recommend setting this parameter to a value greater than the amount of data you typically ingest into the delivery stream in 10 seconds. For example, if you typically ingest data at 1 MB/sec, the value should be 10 MB or higher.
    
    
    
    RetryOptions (dict) --The retry behavior in the event that Firehose is unable to deliver documents to Amazon ES. The default value is 300 (5 minutes).
    
    DurationInSeconds (integer) --After an initial failure to deliver to Amazon ES, the total amount of time during which Firehose re-attempts delivery (including the first attempt). After this time has elapsed, the failed documents are written to Amazon S3. Default value is 300 seconds (5 minutes). A value of 0 (zero) results in no retries.
    
    
    
    S3BackupMode (string) --Defines how documents should be delivered to Amazon S3. When set to FailedDocumentsOnly, Firehose writes any documents that could not be indexed to the configured Amazon S3 destination, with elasticsearch-failed/ appended to the key prefix. When set to AllDocuments, Firehose delivers all incoming records to Amazon S3, and also writes failed documents with elasticsearch-failed/ appended to the prefix. For more information, see Amazon S3 Backup for Amazon Elasticsearch Service Destination . Default value is FailedDocumentsOnly.
    
    S3Configuration (dict) -- [REQUIRED]The configuration for the intermediate Amazon S3 location from which Amazon ES obtains data.
    
    RoleARN (string) -- [REQUIRED]The ARN of the AWS credentials.
    
    BucketARN (string) -- [REQUIRED]The ARN of the S3 bucket.
    
    Prefix (string) --The "YYYY/MM/DD/HH" time format prefix is automatically used for delivered S3 files. You can specify an extra prefix to be added in front of the time format prefix. Note that if the prefix ends with a slash, it appears as a folder in the S3 bucket. For more information, see Amazon S3 Object Name Format in the Amazon Kinesis Firehose Developer Guide .
    
    BufferingHints (dict) --The buffering option. If no value is specified, BufferingHints object default values are used.
    
    SizeInMBs (integer) --Buffer incoming data to the specified size, in MBs, before delivering it to the destination. The default value is 5.
    We recommend setting this parameter to a value greater than the amount of data you typically ingest into the delivery stream in 10 seconds. For example, if you typically ingest data at 1 MB/sec, the value should be 10 MB or higher.
    
    IntervalInSeconds (integer) --Buffer incoming data for the specified period of time, in seconds, before delivering it to the destination. The default value is 300.
    
    
    
    CompressionFormat (string) --The compression format. If no value is specified, the default is UNCOMPRESSED .
    The compression formats SNAPPY or ZIP cannot be specified for Amazon Redshift destinations because they are not supported by the Amazon Redshift COPY operation that reads from the S3 bucket.
    
    EncryptionConfiguration (dict) --The encryption configuration. If no value is specified, the default is no encryption.
    
    NoEncryptionConfig (string) --Specifically override existing encryption information to ensure no encryption is used.
    
    KMSEncryptionConfig (dict) --The encryption key.
    
    AWSKMSKeyARN (string) -- [REQUIRED]The ARN of the encryption key. Must belong to the same region as the destination Amazon S3 bucket.
    
    
    
    
    
    CloudWatchLoggingOptions (dict) --The CloudWatch logging options for your delivery stream.
    
    Enabled (boolean) --Enables or disables CloudWatch logging.
    
    LogGroupName (string) --The CloudWatch group name for logging. This value is required if CloudWatch logging is enabled.
    
    LogStreamName (string) --The CloudWatch log stream name for logging. This value is required if CloudWatch logging is enabled.
    
    
    
    
    
    ProcessingConfiguration (dict) --The data processing configuration.
    
    Enabled (boolean) --Enables or disables data processing.
    
    Processors (list) --The data processors.
    
    (dict) --Describes a data processor.
    
    Type (string) -- [REQUIRED]The type of processor.
    
    Parameters (list) --The processor parameters.
    
    (dict) --Describes the processor parameter.
    
    ParameterName (string) -- [REQUIRED]The name of the parameter.
    
    ParameterValue (string) -- [REQUIRED]The parameter value.
    
    
    
    
    
    
    
    
    
    
    
    CloudWatchLoggingOptions (dict) --The CloudWatch logging options for your delivery stream.
    
    Enabled (boolean) --Enables or disables CloudWatch logging.
    
    LogGroupName (string) --The CloudWatch group name for logging. This value is required if CloudWatch logging is enabled.
    
    LogStreamName (string) --The CloudWatch log stream name for logging. This value is required if CloudWatch logging is enabled.
    
    
    
    
    
    
    """
    pass

def delete_delivery_stream(DeliveryStreamName=None):
    """
    Deletes a delivery stream and its data.
    You can delete a delivery stream only if it is in ACTIVE or DELETING state, and not in the CREATING state. While the deletion request is in process, the delivery stream is in the DELETING state.
    To check the state of a delivery stream, use  DescribeDeliveryStream .
    While the delivery stream is DELETING state, the service may continue to accept the records, but the service doesn't make any guarantees with respect to delivering the data. Therefore, as a best practice, you should first stop any applications that are sending records before deleting a delivery stream.
    See also: AWS API Documentation
    
    
    :example: response = client.delete_delivery_stream(
        DeliveryStreamName='string'
    )
    
    
    :type DeliveryStreamName: string
    :param DeliveryStreamName: [REQUIRED]
            The name of the delivery stream.
            

    :rtype: dict
    :return: {}
    
    
    """
    pass

def describe_delivery_stream(DeliveryStreamName=None, Limit=None, ExclusiveStartDestinationId=None):
    """
    Describes the specified delivery stream and gets the status. For example, after your delivery stream is created, call  DescribeDeliveryStream to see if the delivery stream is ACTIVE and therefore ready for data to be sent to it.
    See also: AWS API Documentation
    
    
    :example: response = client.describe_delivery_stream(
        DeliveryStreamName='string',
        Limit=123,
        ExclusiveStartDestinationId='string'
    )
    
    
    :type DeliveryStreamName: string
    :param DeliveryStreamName: [REQUIRED]
            The name of the delivery stream.
            

    :type Limit: integer
    :param Limit: The limit on the number of destinations to return. Currently, you can have one destination per delivery stream.

    :type ExclusiveStartDestinationId: string
    :param ExclusiveStartDestinationId: The ID of the destination to start returning the destination information. Currently Firehose supports one destination per delivery stream.

    :rtype: dict
    :return: {
        'DeliveryStreamDescription': {
            'DeliveryStreamName': 'string',
            'DeliveryStreamARN': 'string',
            'DeliveryStreamStatus': 'CREATING'|'DELETING'|'ACTIVE',
            'VersionId': 'string',
            'CreateTimestamp': datetime(2015, 1, 1),
            'LastUpdateTimestamp': datetime(2015, 1, 1),
            'Destinations': [
                {
                    'DestinationId': 'string',
                    'S3DestinationDescription': {
                        'RoleARN': 'string',
                        'BucketARN': 'string',
                        'Prefix': 'string',
                        'BufferingHints': {
                            'SizeInMBs': 123,
                            'IntervalInSeconds': 123
                        },
                        'CompressionFormat': 'UNCOMPRESSED'|'GZIP'|'ZIP'|'Snappy',
                        'EncryptionConfiguration': {
                            'NoEncryptionConfig': 'NoEncryption',
                            'KMSEncryptionConfig': {
                                'AWSKMSKeyARN': 'string'
                            }
                        },
                        'CloudWatchLoggingOptions': {
                            'Enabled': True|False,
                            'LogGroupName': 'string',
                            'LogStreamName': 'string'
                        }
                    },
                    'ExtendedS3DestinationDescription': {
                        'RoleARN': 'string',
                        'BucketARN': 'string',
                        'Prefix': 'string',
                        'BufferingHints': {
                            'SizeInMBs': 123,
                            'IntervalInSeconds': 123
                        },
                        'CompressionFormat': 'UNCOMPRESSED'|'GZIP'|'ZIP'|'Snappy',
                        'EncryptionConfiguration': {
                            'NoEncryptionConfig': 'NoEncryption',
                            'KMSEncryptionConfig': {
                                'AWSKMSKeyARN': 'string'
                            }
                        },
                        'CloudWatchLoggingOptions': {
                            'Enabled': True|False,
                            'LogGroupName': 'string',
                            'LogStreamName': 'string'
                        },
                        'ProcessingConfiguration': {
                            'Enabled': True|False,
                            'Processors': [
                                {
                                    'Type': 'Lambda',
                                    'Parameters': [
                                        {
                                            'ParameterName': 'LambdaArn'|'NumberOfRetries',
                                            'ParameterValue': 'string'
                                        },
                                    ]
                                },
                            ]
                        },
                        'S3BackupMode': 'Disabled'|'Enabled',
                        'S3BackupDescription': {
                            'RoleARN': 'string',
                            'BucketARN': 'string',
                            'Prefix': 'string',
                            'BufferingHints': {
                                'SizeInMBs': 123,
                                'IntervalInSeconds': 123
                            },
                            'CompressionFormat': 'UNCOMPRESSED'|'GZIP'|'ZIP'|'Snappy',
                            'EncryptionConfiguration': {
                                'NoEncryptionConfig': 'NoEncryption',
                                'KMSEncryptionConfig': {
                                    'AWSKMSKeyARN': 'string'
                                }
                            },
                            'CloudWatchLoggingOptions': {
                                'Enabled': True|False,
                                'LogGroupName': 'string',
                                'LogStreamName': 'string'
                            }
                        }
                    },
                    'RedshiftDestinationDescription': {
                        'RoleARN': 'string',
                        'ClusterJDBCURL': 'string',
                        'CopyCommand': {
                            'DataTableName': 'string',
                            'DataTableColumns': 'string',
                            'CopyOptions': 'string'
                        },
                        'Username': 'string',
                        'RetryOptions': {
                            'DurationInSeconds': 123
                        },
                        'S3DestinationDescription': {
                            'RoleARN': 'string',
                            'BucketARN': 'string',
                            'Prefix': 'string',
                            'BufferingHints': {
                                'SizeInMBs': 123,
                                'IntervalInSeconds': 123
                            },
                            'CompressionFormat': 'UNCOMPRESSED'|'GZIP'|'ZIP'|'Snappy',
                            'EncryptionConfiguration': {
                                'NoEncryptionConfig': 'NoEncryption',
                                'KMSEncryptionConfig': {
                                    'AWSKMSKeyARN': 'string'
                                }
                            },
                            'CloudWatchLoggingOptions': {
                                'Enabled': True|False,
                                'LogGroupName': 'string',
                                'LogStreamName': 'string'
                            }
                        },
                        'ProcessingConfiguration': {
                            'Enabled': True|False,
                            'Processors': [
                                {
                                    'Type': 'Lambda',
                                    'Parameters': [
                                        {
                                            'ParameterName': 'LambdaArn'|'NumberOfRetries',
                                            'ParameterValue': 'string'
                                        },
                                    ]
                                },
                            ]
                        },
                        'S3BackupMode': 'Disabled'|'Enabled',
                        'S3BackupDescription': {
                            'RoleARN': 'string',
                            'BucketARN': 'string',
                            'Prefix': 'string',
                            'BufferingHints': {
                                'SizeInMBs': 123,
                                'IntervalInSeconds': 123
                            },
                            'CompressionFormat': 'UNCOMPRESSED'|'GZIP'|'ZIP'|'Snappy',
                            'EncryptionConfiguration': {
                                'NoEncryptionConfig': 'NoEncryption',
                                'KMSEncryptionConfig': {
                                    'AWSKMSKeyARN': 'string'
                                }
                            },
                            'CloudWatchLoggingOptions': {
                                'Enabled': True|False,
                                'LogGroupName': 'string',
                                'LogStreamName': 'string'
                            }
                        },
                        'CloudWatchLoggingOptions': {
                            'Enabled': True|False,
                            'LogGroupName': 'string',
                            'LogStreamName': 'string'
                        }
                    },
                    'ElasticsearchDestinationDescription': {
                        'RoleARN': 'string',
                        'DomainARN': 'string',
                        'IndexName': 'string',
                        'TypeName': 'string',
                        'IndexRotationPeriod': 'NoRotation'|'OneHour'|'OneDay'|'OneWeek'|'OneMonth',
                        'BufferingHints': {
                            'IntervalInSeconds': 123,
                            'SizeInMBs': 123
                        },
                        'RetryOptions': {
                            'DurationInSeconds': 123
                        },
                        'S3BackupMode': 'FailedDocumentsOnly'|'AllDocuments',
                        'S3DestinationDescription': {
                            'RoleARN': 'string',
                            'BucketARN': 'string',
                            'Prefix': 'string',
                            'BufferingHints': {
                                'SizeInMBs': 123,
                                'IntervalInSeconds': 123
                            },
                            'CompressionFormat': 'UNCOMPRESSED'|'GZIP'|'ZIP'|'Snappy',
                            'EncryptionConfiguration': {
                                'NoEncryptionConfig': 'NoEncryption',
                                'KMSEncryptionConfig': {
                                    'AWSKMSKeyARN': 'string'
                                }
                            },
                            'CloudWatchLoggingOptions': {
                                'Enabled': True|False,
                                'LogGroupName': 'string',
                                'LogStreamName': 'string'
                            }
                        },
                        'ProcessingConfiguration': {
                            'Enabled': True|False,
                            'Processors': [
                                {
                                    'Type': 'Lambda',
                                    'Parameters': [
                                        {
                                            'ParameterName': 'LambdaArn'|'NumberOfRetries',
                                            'ParameterValue': 'string'
                                        },
                                    ]
                                },
                            ]
                        },
                        'CloudWatchLoggingOptions': {
                            'Enabled': True|False,
                            'LogGroupName': 'string',
                            'LogStreamName': 'string'
                        }
                    }
                },
            ],
            'HasMoreDestinations': True|False
        }
    }
    
    
    """
    pass

def generate_presigned_url(ClientMethod=None, Params=None, ExpiresIn=None, HttpMethod=None):
    """
    Generate a presigned url given a client, its method, and arguments
    
    :type ClientMethod: string
    :param ClientMethod: The client method to presign for

    :type Params: dict
    :param Params: The parameters normally passed to
            ClientMethod.

    :type ExpiresIn: int
    :param ExpiresIn: The number of seconds the presigned url is valid
            for. By default it expires in an hour (3600 seconds)

    :type HttpMethod: string
    :param HttpMethod: The http method to use on the generated url. By
            default, the http method is whatever is used in the method's model.

    """
    pass

def get_paginator(operation_name=None):
    """
    Create a paginator for an operation.
    
    :type operation_name: string
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').

    :rtype: L{botocore.paginate.Paginator}
    """
    pass

def get_waiter():
    """
    
    """
    pass

def list_delivery_streams(Limit=None, ExclusiveStartDeliveryStreamName=None):
    """
    Lists your delivery streams.
    The number of delivery streams might be too large to return using a single call to  ListDeliveryStreams . You can limit the number of delivery streams returned, using the Limit parameter. To determine whether there are more delivery streams to list, check the value of HasMoreDeliveryStreams in the output. If there are more delivery streams to list, you can request them by specifying the name of the last delivery stream returned in the call in the ExclusiveStartDeliveryStreamName parameter of a subsequent call.
    See also: AWS API Documentation
    
    
    :example: response = client.list_delivery_streams(
        Limit=123,
        ExclusiveStartDeliveryStreamName='string'
    )
    
    
    :type Limit: integer
    :param Limit: The maximum number of delivery streams to list.

    :type ExclusiveStartDeliveryStreamName: string
    :param ExclusiveStartDeliveryStreamName: The name of the delivery stream to start the list with.

    :rtype: dict
    :return: {
        'DeliveryStreamNames': [
            'string',
        ],
        'HasMoreDeliveryStreams': True|False
    }
    
    
    :returns: 
    (string) --
    
    """
    pass

def put_record(DeliveryStreamName=None, Record=None):
    """
    Writes a single data record into an Amazon Kinesis Firehose delivery stream. To write multiple data records into a delivery stream, use  PutRecordBatch . Applications using these operations are referred to as producers.
    By default, each delivery stream can take in up to 2,000 transactions per second, 5,000 records per second, or 5 MB per second. Note that if you use  PutRecord and  PutRecordBatch , the limits are an aggregate across these two operations for each delivery stream. For more information about limits and how to request an increase, see Amazon Kinesis Firehose Limits .
    You must specify the name of the delivery stream and the data record when using  PutRecord . The data record consists of a data blob that can be up to 1,000 KB in size, and any kind of data, for example, a segment from a log file, geographic location data, web site clickstream data, etc.
    Firehose buffers records before delivering them to the destination. To disambiguate the data blobs at the destination, a common solution is to use delimiters in the data, such as a newline (\n ) or some other character unique within the data. This allows the consumer application(s) to parse individual data items when reading the data from the destination.
    The  PutRecord operation returns a RecordId , which is a unique string assigned to each record. Producer applications can use this ID for purposes such as auditability and investigation.
    If the  PutRecord operation throws a ServiceUnavailableException , back off and retry. If the exception persists, it is possible that the throughput limits have been exceeded for the delivery stream.
    Data records sent to Firehose are stored for 24 hours from the time they are added to a delivery stream as it attempts to send the records to the destination. If the destination is unreachable for more than 24 hours, the data is no longer available.
    See also: AWS API Documentation
    
    
    :example: response = client.put_record(
        DeliveryStreamName='string',
        Record={
            'Data': b'bytes'
        }
    )
    
    
    :type DeliveryStreamName: string
    :param DeliveryStreamName: [REQUIRED]
            The name of the delivery stream.
            

    :type Record: dict
    :param Record: [REQUIRED]
            The record.
            Data (bytes) -- [REQUIRED]The data blob, which is base64-encoded when the blob is serialized. The maximum size of the data blob, before base64-encoding, is 1,000 KB.
            

    :rtype: dict
    :return: {
        'RecordId': 'string'
    }
    
    
    """
    pass

def put_record_batch(DeliveryStreamName=None, Records=None):
    """
    Writes multiple data records into a delivery stream in a single call, which can achieve higher throughput per producer than when writing single records. To write single data records into a delivery stream, use  PutRecord . Applications using these operations are referred to as producers.
    By default, each delivery stream can take in up to 2,000 transactions per second, 5,000 records per second, or 5 MB per second. Note that if you use  PutRecord and  PutRecordBatch , the limits are an aggregate across these two operations for each delivery stream. For more information about limits, see Amazon Kinesis Firehose Limits .
    Each  PutRecordBatch request supports up to 500 records. Each record in the request can be as large as 1,000 KB (before 64-bit encoding), up to a limit of 4 MB for the entire request. These limits cannot be changed.
    You must specify the name of the delivery stream and the data record when using  PutRecord . The data record consists of a data blob that can be up to 1,000 KB in size, and any kind of data, for example, a segment from a log file, geographic location data, web site clickstream data, and so on.
    Firehose buffers records before delivering them to the destination. To disambiguate the data blobs at the destination, a common solution is to use delimiters in the data, such as a newline (\n ) or some other character unique within the data. This allows the consumer application(s) to parse individual data items when reading the data from the destination.
    The  PutRecordBatch response includes a count of failed records, FailedPutCount , and an array of responses, RequestResponses . Each entry in the RequestResponses array provides additional information about the processed record, and directly correlates with a record in the request array using the same ordering, from the top to the bottom. The response array always includes the same number of records as the request array. RequestResponses includes both successfully and unsuccessfully processed records. Firehose attempts to process all records in each  PutRecordBatch request. A single record failure does not stop the processing of subsequent records.
    A successfully processed record includes a RecordId value, which is unique for the record. An unsuccessfully processed record includes ErrorCode and ErrorMessage values. ErrorCode reflects the type of error, and is one of the following values: ServiceUnavailable or InternalFailure . ErrorMessage provides more detailed information about the error.
    If there is an internal server error or a timeout, the write might have completed or it might have failed. If FailedPutCount is greater than 0, retry the request, resending only those records that might have failed processing. This minimizes the possible duplicate records and also reduces the total bytes sent (and corresponding charges). We recommend that you handle any duplicates at the destination.
    If  PutRecordBatch throws ServiceUnavailableException , back off and retry. If the exception persists, it is possible that the throughput limits have been exceeded for the delivery stream.
    Data records sent to Firehose are stored for 24 hours from the time they are added to a delivery stream as it attempts to send the records to the destination. If the destination is unreachable for more than 24 hours, the data is no longer available.
    See also: AWS API Documentation
    
    
    :example: response = client.put_record_batch(
        DeliveryStreamName='string',
        Records=[
            {
                'Data': b'bytes'
            },
        ]
    )
    
    
    :type DeliveryStreamName: string
    :param DeliveryStreamName: [REQUIRED]
            The name of the delivery stream.
            

    :type Records: list
    :param Records: [REQUIRED]
            One or more records.
            (dict) --The unit of data in a delivery stream.
            Data (bytes) -- [REQUIRED]The data blob, which is base64-encoded when the blob is serialized. The maximum size of the data blob, before base64-encoding, is 1,000 KB.
            
            

    :rtype: dict
    :return: {
        'FailedPutCount': 123,
        'RequestResponses': [
            {
                'RecordId': 'string',
                'ErrorCode': 'string',
                'ErrorMessage': 'string'
            },
        ]
    }
    
    
    """
    pass

def update_destination(DeliveryStreamName=None, CurrentDeliveryStreamVersionId=None, DestinationId=None, S3DestinationUpdate=None, ExtendedS3DestinationUpdate=None, RedshiftDestinationUpdate=None, ElasticsearchDestinationUpdate=None):
    """
    Updates the specified destination of the specified delivery stream.
    You can use this operation to change the destination type (for example, to replace the Amazon S3 destination with Amazon Redshift) or change the parameters associated with a destination (for example, to change the bucket name of the Amazon S3 destination). The update might not occur immediately. The target delivery stream remains active while the configurations are updated, so data writes to the delivery stream can continue during this process. The updated configurations are usually effective within a few minutes.
    Note that switching between Amazon ES and other services is not supported. For an Amazon ES destination, you can only update to another Amazon ES destination.
    If the destination type is the same, Firehose merges the configuration parameters specified with the destination configuration that already exists on the delivery stream. If any of the parameters are not specified in the call, the existing values are retained. For example, in the Amazon S3 destination, if  EncryptionConfiguration is not specified then the existing  EncryptionConfiguration is maintained on the destination.
    If the destination type is not the same, for example, changing the destination from Amazon S3 to Amazon Redshift, Firehose does not merge any parameters. In this case, all parameters must be specified.
    Firehose uses CurrentDeliveryStreamVersionId to avoid race conditions and conflicting merges. This is a required field, and the service updates the configuration only if the existing configuration has a version ID that matches. After the update is applied successfully, the version ID is updated, and can be retrieved using  DescribeDeliveryStream . You should use the new version ID to set CurrentDeliveryStreamVersionId in the next call.
    See also: AWS API Documentation
    
    
    :example: response = client.update_destination(
        DeliveryStreamName='string',
        CurrentDeliveryStreamVersionId='string',
        DestinationId='string',
        S3DestinationUpdate={
            'RoleARN': 'string',
            'BucketARN': 'string',
            'Prefix': 'string',
            'BufferingHints': {
                'SizeInMBs': 123,
                'IntervalInSeconds': 123
            },
            'CompressionFormat': 'UNCOMPRESSED'|'GZIP'|'ZIP'|'Snappy',
            'EncryptionConfiguration': {
                'NoEncryptionConfig': 'NoEncryption',
                'KMSEncryptionConfig': {
                    'AWSKMSKeyARN': 'string'
                }
            },
            'CloudWatchLoggingOptions': {
                'Enabled': True|False,
                'LogGroupName': 'string',
                'LogStreamName': 'string'
            }
        },
        ExtendedS3DestinationUpdate={
            'RoleARN': 'string',
            'BucketARN': 'string',
            'Prefix': 'string',
            'BufferingHints': {
                'SizeInMBs': 123,
                'IntervalInSeconds': 123
            },
            'CompressionFormat': 'UNCOMPRESSED'|'GZIP'|'ZIP'|'Snappy',
            'EncryptionConfiguration': {
                'NoEncryptionConfig': 'NoEncryption',
                'KMSEncryptionConfig': {
                    'AWSKMSKeyARN': 'string'
                }
            },
            'CloudWatchLoggingOptions': {
                'Enabled': True|False,
                'LogGroupName': 'string',
                'LogStreamName': 'string'
            },
            'ProcessingConfiguration': {
                'Enabled': True|False,
                'Processors': [
                    {
                        'Type': 'Lambda',
                        'Parameters': [
                            {
                                'ParameterName': 'LambdaArn'|'NumberOfRetries',
                                'ParameterValue': 'string'
                            },
                        ]
                    },
                ]
            },
            'S3BackupMode': 'Disabled'|'Enabled',
            'S3BackupUpdate': {
                'RoleARN': 'string',
                'BucketARN': 'string',
                'Prefix': 'string',
                'BufferingHints': {
                    'SizeInMBs': 123,
                    'IntervalInSeconds': 123
                },
                'CompressionFormat': 'UNCOMPRESSED'|'GZIP'|'ZIP'|'Snappy',
                'EncryptionConfiguration': {
                    'NoEncryptionConfig': 'NoEncryption',
                    'KMSEncryptionConfig': {
                        'AWSKMSKeyARN': 'string'
                    }
                },
                'CloudWatchLoggingOptions': {
                    'Enabled': True|False,
                    'LogGroupName': 'string',
                    'LogStreamName': 'string'
                }
            }
        },
        RedshiftDestinationUpdate={
            'RoleARN': 'string',
            'ClusterJDBCURL': 'string',
            'CopyCommand': {
                'DataTableName': 'string',
                'DataTableColumns': 'string',
                'CopyOptions': 'string'
            },
            'Username': 'string',
            'Password': 'string',
            'RetryOptions': {
                'DurationInSeconds': 123
            },
            'S3Update': {
                'RoleARN': 'string',
                'BucketARN': 'string',
                'Prefix': 'string',
                'BufferingHints': {
                    'SizeInMBs': 123,
                    'IntervalInSeconds': 123
                },
                'CompressionFormat': 'UNCOMPRESSED'|'GZIP'|'ZIP'|'Snappy',
                'EncryptionConfiguration': {
                    'NoEncryptionConfig': 'NoEncryption',
                    'KMSEncryptionConfig': {
                        'AWSKMSKeyARN': 'string'
                    }
                },
                'CloudWatchLoggingOptions': {
                    'Enabled': True|False,
                    'LogGroupName': 'string',
                    'LogStreamName': 'string'
                }
            },
            'ProcessingConfiguration': {
                'Enabled': True|False,
                'Processors': [
                    {
                        'Type': 'Lambda',
                        'Parameters': [
                            {
                                'ParameterName': 'LambdaArn'|'NumberOfRetries',
                                'ParameterValue': 'string'
                            },
                        ]
                    },
                ]
            },
            'S3BackupMode': 'Disabled'|'Enabled',
            'S3BackupUpdate': {
                'RoleARN': 'string',
                'BucketARN': 'string',
                'Prefix': 'string',
                'BufferingHints': {
                    'SizeInMBs': 123,
                    'IntervalInSeconds': 123
                },
                'CompressionFormat': 'UNCOMPRESSED'|'GZIP'|'ZIP'|'Snappy',
                'EncryptionConfiguration': {
                    'NoEncryptionConfig': 'NoEncryption',
                    'KMSEncryptionConfig': {
                        'AWSKMSKeyARN': 'string'
                    }
                },
                'CloudWatchLoggingOptions': {
                    'Enabled': True|False,
                    'LogGroupName': 'string',
                    'LogStreamName': 'string'
                }
            },
            'CloudWatchLoggingOptions': {
                'Enabled': True|False,
                'LogGroupName': 'string',
                'LogStreamName': 'string'
            }
        },
        ElasticsearchDestinationUpdate={
            'RoleARN': 'string',
            'DomainARN': 'string',
            'IndexName': 'string',
            'TypeName': 'string',
            'IndexRotationPeriod': 'NoRotation'|'OneHour'|'OneDay'|'OneWeek'|'OneMonth',
            'BufferingHints': {
                'IntervalInSeconds': 123,
                'SizeInMBs': 123
            },
            'RetryOptions': {
                'DurationInSeconds': 123
            },
            'S3Update': {
                'RoleARN': 'string',
                'BucketARN': 'string',
                'Prefix': 'string',
                'BufferingHints': {
                    'SizeInMBs': 123,
                    'IntervalInSeconds': 123
                },
                'CompressionFormat': 'UNCOMPRESSED'|'GZIP'|'ZIP'|'Snappy',
                'EncryptionConfiguration': {
                    'NoEncryptionConfig': 'NoEncryption',
                    'KMSEncryptionConfig': {
                        'AWSKMSKeyARN': 'string'
                    }
                },
                'CloudWatchLoggingOptions': {
                    'Enabled': True|False,
                    'LogGroupName': 'string',
                    'LogStreamName': 'string'
                }
            },
            'ProcessingConfiguration': {
                'Enabled': True|False,
                'Processors': [
                    {
                        'Type': 'Lambda',
                        'Parameters': [
                            {
                                'ParameterName': 'LambdaArn'|'NumberOfRetries',
                                'ParameterValue': 'string'
                            },
                        ]
                    },
                ]
            },
            'CloudWatchLoggingOptions': {
                'Enabled': True|False,
                'LogGroupName': 'string',
                'LogStreamName': 'string'
            }
        }
    )
    
    
    :type DeliveryStreamName: string
    :param DeliveryStreamName: [REQUIRED]
            The name of the delivery stream.
            

    :type CurrentDeliveryStreamVersionId: string
    :param CurrentDeliveryStreamVersionId: [REQUIRED]
            Obtain this value from the VersionId result of DeliveryStreamDescription . This value is required, and helps the service to perform conditional operations. For example, if there is a interleaving update and this value is null, then the update destination fails. After the update is successful, the VersionId value is updated. The service then performs a merge of the old configuration with the new configuration.
            

    :type DestinationId: string
    :param DestinationId: [REQUIRED]
            The ID of the destination.
            

    :type S3DestinationUpdate: dict
    :param S3DestinationUpdate: [Deprecated] Describes an update for a destination in Amazon S3.
            RoleARN (string) --The ARN of the AWS credentials.
            BucketARN (string) --The ARN of the S3 bucket.
            Prefix (string) --The 'YYYY/MM/DD/HH' time format prefix is automatically used for delivered S3 files. You can specify an extra prefix to be added in front of the time format prefix. Note that if the prefix ends with a slash, it appears as a folder in the S3 bucket. For more information, see Amazon S3 Object Name Format in the Amazon Kinesis Firehose Developer Guide .
            BufferingHints (dict) --The buffering option. If no value is specified, BufferingHints object default values are used.
            SizeInMBs (integer) --Buffer incoming data to the specified size, in MBs, before delivering it to the destination. The default value is 5.
            We recommend setting this parameter to a value greater than the amount of data you typically ingest into the delivery stream in 10 seconds. For example, if you typically ingest data at 1 MB/sec, the value should be 10 MB or higher.
            IntervalInSeconds (integer) --Buffer incoming data for the specified period of time, in seconds, before delivering it to the destination. The default value is 300.
            CompressionFormat (string) --The compression format. If no value is specified, the default is UNCOMPRESSED .
            The compression formats SNAPPY or ZIP cannot be specified for Amazon Redshift destinations because they are not supported by the Amazon Redshift COPY operation that reads from the S3 bucket.
            EncryptionConfiguration (dict) --The encryption configuration. If no value is specified, the default is no encryption.
            NoEncryptionConfig (string) --Specifically override existing encryption information to ensure no encryption is used.
            KMSEncryptionConfig (dict) --The encryption key.
            AWSKMSKeyARN (string) -- [REQUIRED]The ARN of the encryption key. Must belong to the same region as the destination Amazon S3 bucket.
            
            CloudWatchLoggingOptions (dict) --The CloudWatch logging options for your delivery stream.
            Enabled (boolean) --Enables or disables CloudWatch logging.
            LogGroupName (string) --The CloudWatch group name for logging. This value is required if CloudWatch logging is enabled.
            LogStreamName (string) --The CloudWatch log stream name for logging. This value is required if CloudWatch logging is enabled.
            
            

    :type ExtendedS3DestinationUpdate: dict
    :param ExtendedS3DestinationUpdate: Describes an update for a destination in Amazon S3.
            RoleARN (string) --The ARN of the AWS credentials.
            BucketARN (string) --The ARN of the S3 bucket.
            Prefix (string) --The 'YYYY/MM/DD/HH' time format prefix is automatically used for delivered S3 files. You can specify an extra prefix to be added in front of the time format prefix. Note that if the prefix ends with a slash, it appears as a folder in the S3 bucket. For more information, see Amazon S3 Object Name Format in the Amazon Kinesis Firehose Developer Guide .
            BufferingHints (dict) --The buffering option.
            SizeInMBs (integer) --Buffer incoming data to the specified size, in MBs, before delivering it to the destination. The default value is 5.
            We recommend setting this parameter to a value greater than the amount of data you typically ingest into the delivery stream in 10 seconds. For example, if you typically ingest data at 1 MB/sec, the value should be 10 MB or higher.
            IntervalInSeconds (integer) --Buffer incoming data for the specified period of time, in seconds, before delivering it to the destination. The default value is 300.
            CompressionFormat (string) --The compression format. If no value is specified, the default is UNCOMPRESSED .
            EncryptionConfiguration (dict) --The encryption configuration. If no value is specified, the default is no encryption.
            NoEncryptionConfig (string) --Specifically override existing encryption information to ensure no encryption is used.
            KMSEncryptionConfig (dict) --The encryption key.
            AWSKMSKeyARN (string) -- [REQUIRED]The ARN of the encryption key. Must belong to the same region as the destination Amazon S3 bucket.
            
            CloudWatchLoggingOptions (dict) --The CloudWatch logging options for your delivery stream.
            Enabled (boolean) --Enables or disables CloudWatch logging.
            LogGroupName (string) --The CloudWatch group name for logging. This value is required if CloudWatch logging is enabled.
            LogStreamName (string) --The CloudWatch log stream name for logging. This value is required if CloudWatch logging is enabled.
            ProcessingConfiguration (dict) --The data processing configuration.
            Enabled (boolean) --Enables or disables data processing.
            Processors (list) --The data processors.
            (dict) --Describes a data processor.
            Type (string) -- [REQUIRED]The type of processor.
            Parameters (list) --The processor parameters.
            (dict) --Describes the processor parameter.
            ParameterName (string) -- [REQUIRED]The name of the parameter.
            ParameterValue (string) -- [REQUIRED]The parameter value.
            
            
            S3BackupMode (string) --Enables or disables Amazon S3 backup mode.
            S3BackupUpdate (dict) --The Amazon S3 destination for backup.
            RoleARN (string) --The ARN of the AWS credentials.
            BucketARN (string) --The ARN of the S3 bucket.
            Prefix (string) --The 'YYYY/MM/DD/HH' time format prefix is automatically used for delivered S3 files. You can specify an extra prefix to be added in front of the time format prefix. Note that if the prefix ends with a slash, it appears as a folder in the S3 bucket. For more information, see Amazon S3 Object Name Format in the Amazon Kinesis Firehose Developer Guide .
            BufferingHints (dict) --The buffering option. If no value is specified, BufferingHints object default values are used.
            SizeInMBs (integer) --Buffer incoming data to the specified size, in MBs, before delivering it to the destination. The default value is 5.
            We recommend setting this parameter to a value greater than the amount of data you typically ingest into the delivery stream in 10 seconds. For example, if you typically ingest data at 1 MB/sec, the value should be 10 MB or higher.
            IntervalInSeconds (integer) --Buffer incoming data for the specified period of time, in seconds, before delivering it to the destination. The default value is 300.
            CompressionFormat (string) --The compression format. If no value is specified, the default is UNCOMPRESSED .
            The compression formats SNAPPY or ZIP cannot be specified for Amazon Redshift destinations because they are not supported by the Amazon Redshift COPY operation that reads from the S3 bucket.
            EncryptionConfiguration (dict) --The encryption configuration. If no value is specified, the default is no encryption.
            NoEncryptionConfig (string) --Specifically override existing encryption information to ensure no encryption is used.
            KMSEncryptionConfig (dict) --The encryption key.
            AWSKMSKeyARN (string) -- [REQUIRED]The ARN of the encryption key. Must belong to the same region as the destination Amazon S3 bucket.
            
            CloudWatchLoggingOptions (dict) --The CloudWatch logging options for your delivery stream.
            Enabled (boolean) --Enables or disables CloudWatch logging.
            LogGroupName (string) --The CloudWatch group name for logging. This value is required if CloudWatch logging is enabled.
            LogStreamName (string) --The CloudWatch log stream name for logging. This value is required if CloudWatch logging is enabled.
            
            

    :type RedshiftDestinationUpdate: dict
    :param RedshiftDestinationUpdate: Describes an update for a destination in Amazon Redshift.
            RoleARN (string) --The ARN of the AWS credentials.
            ClusterJDBCURL (string) --The database connection string.
            CopyCommand (dict) --The COPY command.
            DataTableName (string) -- [REQUIRED]The name of the target table. The table must already exist in the database.
            DataTableColumns (string) --A comma-separated list of column names.
            CopyOptions (string) --Optional parameters to use with the Amazon Redshift COPY command. For more information, see the 'Optional Parameters' section of Amazon Redshift COPY command . Some possible examples that would apply to Firehose are as follows:
            delimiter '\t' lzop; - fields are delimited with 't' (TAB character) and compressed using lzop.delimiter '| - fields are delimited with '|' (this is the default delimiter).
            delimiter '|' escape - the delimiter should be escaped.
            fixedwidth 'venueid:3,venuename:25,venuecity:12,venuestate:2,venueseats:6' - fields are fixed width in the source, with each width specified after every column in the table.
            JSON 's3://mybucket/jsonpaths.txt' - data is in JSON format, and the path specified is the format of the data.
            For more examples, see Amazon Redshift COPY command examples .
            Username (string) --The name of the user.
            Password (string) --The user password.
            RetryOptions (dict) --The retry behavior in the event that Firehose is unable to deliver documents to Amazon Redshift. Default value is 3600 (60 minutes).
            DurationInSeconds (integer) --The length of time during which Firehose retries delivery after a failure, starting from the initial request and including the first attempt. The default value is 3600 seconds (60 minutes). Firehose does not retry if the value of DurationInSeconds is 0 (zero) or if the first delivery attempt takes longer than the current value.
            S3Update (dict) --The Amazon S3 destination.
            The compression formats SNAPPY or ZIP cannot be specified in RedshiftDestinationUpdate.S3Update because the Amazon Redshift COPY operation that reads from the S3 bucket doesn't support these compression formats.
            RoleARN (string) --The ARN of the AWS credentials.
            BucketARN (string) --The ARN of the S3 bucket.
            Prefix (string) --The 'YYYY/MM/DD/HH' time format prefix is automatically used for delivered S3 files. You can specify an extra prefix to be added in front of the time format prefix. Note that if the prefix ends with a slash, it appears as a folder in the S3 bucket. For more information, see Amazon S3 Object Name Format in the Amazon Kinesis Firehose Developer Guide .
            BufferingHints (dict) --The buffering option. If no value is specified, BufferingHints object default values are used.
            SizeInMBs (integer) --Buffer incoming data to the specified size, in MBs, before delivering it to the destination. The default value is 5.
            We recommend setting this parameter to a value greater than the amount of data you typically ingest into the delivery stream in 10 seconds. For example, if you typically ingest data at 1 MB/sec, the value should be 10 MB or higher.
            IntervalInSeconds (integer) --Buffer incoming data for the specified period of time, in seconds, before delivering it to the destination. The default value is 300.
            CompressionFormat (string) --The compression format. If no value is specified, the default is UNCOMPRESSED .
            The compression formats SNAPPY or ZIP cannot be specified for Amazon Redshift destinations because they are not supported by the Amazon Redshift COPY operation that reads from the S3 bucket.
            EncryptionConfiguration (dict) --The encryption configuration. If no value is specified, the default is no encryption.
            NoEncryptionConfig (string) --Specifically override existing encryption information to ensure no encryption is used.
            KMSEncryptionConfig (dict) --The encryption key.
            AWSKMSKeyARN (string) -- [REQUIRED]The ARN of the encryption key. Must belong to the same region as the destination Amazon S3 bucket.
            
            CloudWatchLoggingOptions (dict) --The CloudWatch logging options for your delivery stream.
            Enabled (boolean) --Enables or disables CloudWatch logging.
            LogGroupName (string) --The CloudWatch group name for logging. This value is required if CloudWatch logging is enabled.
            LogStreamName (string) --The CloudWatch log stream name for logging. This value is required if CloudWatch logging is enabled.
            
            ProcessingConfiguration (dict) --The data processing configuration.
            Enabled (boolean) --Enables or disables data processing.
            Processors (list) --The data processors.
            (dict) --Describes a data processor.
            Type (string) -- [REQUIRED]The type of processor.
            Parameters (list) --The processor parameters.
            (dict) --Describes the processor parameter.
            ParameterName (string) -- [REQUIRED]The name of the parameter.
            ParameterValue (string) -- [REQUIRED]The parameter value.
            
            
            S3BackupMode (string) --The Amazon S3 backup mode.
            S3BackupUpdate (dict) --The Amazon S3 destination for backup.
            RoleARN (string) --The ARN of the AWS credentials.
            BucketARN (string) --The ARN of the S3 bucket.
            Prefix (string) --The 'YYYY/MM/DD/HH' time format prefix is automatically used for delivered S3 files. You can specify an extra prefix to be added in front of the time format prefix. Note that if the prefix ends with a slash, it appears as a folder in the S3 bucket. For more information, see Amazon S3 Object Name Format in the Amazon Kinesis Firehose Developer Guide .
            BufferingHints (dict) --The buffering option. If no value is specified, BufferingHints object default values are used.
            SizeInMBs (integer) --Buffer incoming data to the specified size, in MBs, before delivering it to the destination. The default value is 5.
            We recommend setting this parameter to a value greater than the amount of data you typically ingest into the delivery stream in 10 seconds. For example, if you typically ingest data at 1 MB/sec, the value should be 10 MB or higher.
            IntervalInSeconds (integer) --Buffer incoming data for the specified period of time, in seconds, before delivering it to the destination. The default value is 300.
            CompressionFormat (string) --The compression format. If no value is specified, the default is UNCOMPRESSED .
            The compression formats SNAPPY or ZIP cannot be specified for Amazon Redshift destinations because they are not supported by the Amazon Redshift COPY operation that reads from the S3 bucket.
            EncryptionConfiguration (dict) --The encryption configuration. If no value is specified, the default is no encryption.
            NoEncryptionConfig (string) --Specifically override existing encryption information to ensure no encryption is used.
            KMSEncryptionConfig (dict) --The encryption key.
            AWSKMSKeyARN (string) -- [REQUIRED]The ARN of the encryption key. Must belong to the same region as the destination Amazon S3 bucket.
            
            CloudWatchLoggingOptions (dict) --The CloudWatch logging options for your delivery stream.
            Enabled (boolean) --Enables or disables CloudWatch logging.
            LogGroupName (string) --The CloudWatch group name for logging. This value is required if CloudWatch logging is enabled.
            LogStreamName (string) --The CloudWatch log stream name for logging. This value is required if CloudWatch logging is enabled.
            
            CloudWatchLoggingOptions (dict) --The CloudWatch logging options for your delivery stream.
            Enabled (boolean) --Enables or disables CloudWatch logging.
            LogGroupName (string) --The CloudWatch group name for logging. This value is required if CloudWatch logging is enabled.
            LogStreamName (string) --The CloudWatch log stream name for logging. This value is required if CloudWatch logging is enabled.
            
            

    :type ElasticsearchDestinationUpdate: dict
    :param ElasticsearchDestinationUpdate: Describes an update for a destination in Amazon ES.
            RoleARN (string) --The ARN of the IAM role to be assumed by Firehose for calling the Amazon ES Configuration API and for indexing documents. For more information, see Amazon S3 Bucket Access .
            DomainARN (string) --The ARN of the Amazon ES domain. The IAM role must have permissions for DescribeElasticsearchDomain , DescribeElasticsearchDomains , and DescribeElasticsearchDomainConfig after assuming the IAM role specified in RoleARN .
            IndexName (string) --The Elasticsearch index name.
            TypeName (string) --The Elasticsearch type name.
            IndexRotationPeriod (string) --The Elasticsearch index rotation period. Index rotation appends a timestamp to IndexName to facilitate the expiration of old data. For more information, see Index Rotation for Amazon Elasticsearch Service Destination . Default value is OneDay .
            BufferingHints (dict) --The buffering options. If no value is specified, ElasticsearchBufferingHints object default values are used.
            IntervalInSeconds (integer) --Buffer incoming data for the specified period of time, in seconds, before delivering it to the destination. The default value is 300 (5 minutes).
            SizeInMBs (integer) --Buffer incoming data to the specified size, in MBs, before delivering it to the destination. The default value is 5.
            We recommend setting this parameter to a value greater than the amount of data you typically ingest into the delivery stream in 10 seconds. For example, if you typically ingest data at 1 MB/sec, the value should be 10 MB or higher.
            RetryOptions (dict) --The retry behavior in the event that Firehose is unable to deliver documents to Amazon ES. Default value is 300 (5 minutes).
            DurationInSeconds (integer) --After an initial failure to deliver to Amazon ES, the total amount of time during which Firehose re-attempts delivery (including the first attempt). After this time has elapsed, the failed documents are written to Amazon S3. Default value is 300 seconds (5 minutes). A value of 0 (zero) results in no retries.
            S3Update (dict) --The Amazon S3 destination.
            RoleARN (string) --The ARN of the AWS credentials.
            BucketARN (string) --The ARN of the S3 bucket.
            Prefix (string) --The 'YYYY/MM/DD/HH' time format prefix is automatically used for delivered S3 files. You can specify an extra prefix to be added in front of the time format prefix. Note that if the prefix ends with a slash, it appears as a folder in the S3 bucket. For more information, see Amazon S3 Object Name Format in the Amazon Kinesis Firehose Developer Guide .
            BufferingHints (dict) --The buffering option. If no value is specified, BufferingHints object default values are used.
            SizeInMBs (integer) --Buffer incoming data to the specified size, in MBs, before delivering it to the destination. The default value is 5.
            We recommend setting this parameter to a value greater than the amount of data you typically ingest into the delivery stream in 10 seconds. For example, if you typically ingest data at 1 MB/sec, the value should be 10 MB or higher.
            IntervalInSeconds (integer) --Buffer incoming data for the specified period of time, in seconds, before delivering it to the destination. The default value is 300.
            CompressionFormat (string) --The compression format. If no value is specified, the default is UNCOMPRESSED .
            The compression formats SNAPPY or ZIP cannot be specified for Amazon Redshift destinations because they are not supported by the Amazon Redshift COPY operation that reads from the S3 bucket.
            EncryptionConfiguration (dict) --The encryption configuration. If no value is specified, the default is no encryption.
            NoEncryptionConfig (string) --Specifically override existing encryption information to ensure no encryption is used.
            KMSEncryptionConfig (dict) --The encryption key.
            AWSKMSKeyARN (string) -- [REQUIRED]The ARN of the encryption key. Must belong to the same region as the destination Amazon S3 bucket.
            
            CloudWatchLoggingOptions (dict) --The CloudWatch logging options for your delivery stream.
            Enabled (boolean) --Enables or disables CloudWatch logging.
            LogGroupName (string) --The CloudWatch group name for logging. This value is required if CloudWatch logging is enabled.
            LogStreamName (string) --The CloudWatch log stream name for logging. This value is required if CloudWatch logging is enabled.
            
            ProcessingConfiguration (dict) --The data processing configuration.
            Enabled (boolean) --Enables or disables data processing.
            Processors (list) --The data processors.
            (dict) --Describes a data processor.
            Type (string) -- [REQUIRED]The type of processor.
            Parameters (list) --The processor parameters.
            (dict) --Describes the processor parameter.
            ParameterName (string) -- [REQUIRED]The name of the parameter.
            ParameterValue (string) -- [REQUIRED]The parameter value.
            
            
            CloudWatchLoggingOptions (dict) --The CloudWatch logging options for your delivery stream.
            Enabled (boolean) --Enables or disables CloudWatch logging.
            LogGroupName (string) --The CloudWatch group name for logging. This value is required if CloudWatch logging is enabled.
            LogStreamName (string) --The CloudWatch log stream name for logging. This value is required if CloudWatch logging is enabled.
            
            

    :rtype: dict
    :return: {}
    
    
    :returns: 
    (dict) --
    
    """
    pass




'''

The MIT License (MIT)

Copyright (c) 2016 WavyCloud

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

'''

def can_paginate(operation_name=None):
    """
    Check if an operation can be paginated.
    
    :type operation_name: string
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').

    """
    pass

def delete_alarms(AlarmNames=None):
    """
    Deletes the specified alarms. In the event of an error, no alarms are deleted.
    See also: AWS API Documentation
    
    
    :example: response = client.delete_alarms(
        AlarmNames=[
            'string',
        ]
    )
    
    
    :type AlarmNames: list
    :param AlarmNames: [REQUIRED]
            The alarms to be deleted.
            (string) --
            

    """
    pass

def describe_alarm_history(AlarmName=None, HistoryItemType=None, StartDate=None, EndDate=None, MaxRecords=None, NextToken=None):
    """
    Retrieves the history for the specified alarm. You can filter the results by date range or item type. If an alarm name is not specified, the histories for all alarms are returned.
    Note that Amazon CloudWatch retains the history of an alarm even if you delete the alarm.
    See also: AWS API Documentation
    
    
    :example: response = client.describe_alarm_history(
        AlarmName='string',
        HistoryItemType='ConfigurationUpdate'|'StateUpdate'|'Action',
        StartDate=datetime(2015, 1, 1),
        EndDate=datetime(2015, 1, 1),
        MaxRecords=123,
        NextToken='string'
    )
    
    
    :type AlarmName: string
    :param AlarmName: The name of the alarm.

    :type HistoryItemType: string
    :param HistoryItemType: The type of alarm histories to retrieve.

    :type StartDate: datetime
    :param StartDate: The starting date to retrieve alarm history.

    :type EndDate: datetime
    :param EndDate: The ending date to retrieve alarm history.

    :type MaxRecords: integer
    :param MaxRecords: The maximum number of alarm history records to retrieve.

    :type NextToken: string
    :param NextToken: The token returned by a previous call to indicate that there is more data available.

    :rtype: dict
    :return: {
        'AlarmHistoryItems': [
            {
                'AlarmName': 'string',
                'Timestamp': datetime(2015, 1, 1),
                'HistoryItemType': 'ConfigurationUpdate'|'StateUpdate'|'Action',
                'HistorySummary': 'string',
                'HistoryData': 'string'
            },
        ],
        'NextToken': 'string'
    }
    
    
    """
    pass

def describe_alarms(AlarmNames=None, AlarmNamePrefix=None, StateValue=None, ActionPrefix=None, MaxRecords=None, NextToken=None):
    """
    Retrieves the specified alarms. If no alarms are specified, all alarms are returned. Alarms can be retrieved by using only a prefix for the alarm name, the alarm state, or a prefix for any action.
    See also: AWS API Documentation
    
    
    :example: response = client.describe_alarms(
        AlarmNames=[
            'string',
        ],
        AlarmNamePrefix='string',
        StateValue='OK'|'ALARM'|'INSUFFICIENT_DATA',
        ActionPrefix='string',
        MaxRecords=123,
        NextToken='string'
    )
    
    
    :type AlarmNames: list
    :param AlarmNames: The names of the alarms.
            (string) --
            

    :type AlarmNamePrefix: string
    :param AlarmNamePrefix: The alarm name prefix. You cannot specify AlarmNames if this parameter is specified.

    :type StateValue: string
    :param StateValue: The state value to be used in matching alarms.

    :type ActionPrefix: string
    :param ActionPrefix: The action name prefix.

    :type MaxRecords: integer
    :param MaxRecords: The maximum number of alarm descriptions to retrieve.

    :type NextToken: string
    :param NextToken: The token returned by a previous call to indicate that there is more data available.

    :rtype: dict
    :return: {
        'MetricAlarms': [
            {
                'AlarmName': 'string',
                'AlarmArn': 'string',
                'AlarmDescription': 'string',
                'AlarmConfigurationUpdatedTimestamp': datetime(2015, 1, 1),
                'ActionsEnabled': True|False,
                'OKActions': [
                    'string',
                ],
                'AlarmActions': [
                    'string',
                ],
                'InsufficientDataActions': [
                    'string',
                ],
                'StateValue': 'OK'|'ALARM'|'INSUFFICIENT_DATA',
                'StateReason': 'string',
                'StateReasonData': 'string',
                'StateUpdatedTimestamp': datetime(2015, 1, 1),
                'MetricName': 'string',
                'Namespace': 'string',
                'Statistic': 'SampleCount'|'Average'|'Sum'|'Minimum'|'Maximum',
                'ExtendedStatistic': 'string',
                'Dimensions': [
                    {
                        'Name': 'string',
                        'Value': 'string'
                    },
                ],
                'Period': 123,
                'Unit': 'Seconds'|'Microseconds'|'Milliseconds'|'Bytes'|'Kilobytes'|'Megabytes'|'Gigabytes'|'Terabytes'|'Bits'|'Kilobits'|'Megabits'|'Gigabits'|'Terabits'|'Percent'|'Count'|'Bytes/Second'|'Kilobytes/Second'|'Megabytes/Second'|'Gigabytes/Second'|'Terabytes/Second'|'Bits/Second'|'Kilobits/Second'|'Megabits/Second'|'Gigabits/Second'|'Terabits/Second'|'Count/Second'|'None',
                'EvaluationPeriods': 123,
                'Threshold': 123.0,
                'ComparisonOperator': 'GreaterThanOrEqualToThreshold'|'GreaterThanThreshold'|'LessThanThreshold'|'LessThanOrEqualToThreshold',
                'TreatMissingData': 'string',
                'EvaluateLowSampleCountPercentile': 'string'
            },
        ],
        'NextToken': 'string'
    }
    
    
    :returns: 
    (string) --
    
    """
    pass

def describe_alarms_for_metric(MetricName=None, Namespace=None, Statistic=None, ExtendedStatistic=None, Dimensions=None, Period=None, Unit=None):
    """
    Retrieves the alarms for the specified metric. Specify a statistic, period, or unit to filter the results.
    See also: AWS API Documentation
    
    
    :example: response = client.describe_alarms_for_metric(
        MetricName='string',
        Namespace='string',
        Statistic='SampleCount'|'Average'|'Sum'|'Minimum'|'Maximum',
        ExtendedStatistic='string',
        Dimensions=[
            {
                'Name': 'string',
                'Value': 'string'
            },
        ],
        Period=123,
        Unit='Seconds'|'Microseconds'|'Milliseconds'|'Bytes'|'Kilobytes'|'Megabytes'|'Gigabytes'|'Terabytes'|'Bits'|'Kilobits'|'Megabits'|'Gigabits'|'Terabits'|'Percent'|'Count'|'Bytes/Second'|'Kilobytes/Second'|'Megabytes/Second'|'Gigabytes/Second'|'Terabytes/Second'|'Bits/Second'|'Kilobits/Second'|'Megabits/Second'|'Gigabits/Second'|'Terabits/Second'|'Count/Second'|'None'
    )
    
    
    :type MetricName: string
    :param MetricName: [REQUIRED]
            The name of the metric.
            

    :type Namespace: string
    :param Namespace: [REQUIRED]
            The namespace of the metric.
            

    :type Statistic: string
    :param Statistic: The statistic for the metric, other than percentiles. For percentile statistics, use ExtendedStatistics .

    :type ExtendedStatistic: string
    :param ExtendedStatistic: The percentile statistic for the metric. Specify a value between p0.0 and p100.

    :type Dimensions: list
    :param Dimensions: The dimensions associated with the metric. If the metric has any associated dimensions, you must specify them in order for the call to succeed.
            (dict) --Expands the identity of a metric.
            Name (string) -- [REQUIRED]The name of the dimension.
            Value (string) -- [REQUIRED]The value representing the dimension measurement.
            
            

    :type Period: integer
    :param Period: The period, in seconds, over which the statistic is applied.

    :type Unit: string
    :param Unit: The unit for the metric.

    :rtype: dict
    :return: {
        'MetricAlarms': [
            {
                'AlarmName': 'string',
                'AlarmArn': 'string',
                'AlarmDescription': 'string',
                'AlarmConfigurationUpdatedTimestamp': datetime(2015, 1, 1),
                'ActionsEnabled': True|False,
                'OKActions': [
                    'string',
                ],
                'AlarmActions': [
                    'string',
                ],
                'InsufficientDataActions': [
                    'string',
                ],
                'StateValue': 'OK'|'ALARM'|'INSUFFICIENT_DATA',
                'StateReason': 'string',
                'StateReasonData': 'string',
                'StateUpdatedTimestamp': datetime(2015, 1, 1),
                'MetricName': 'string',
                'Namespace': 'string',
                'Statistic': 'SampleCount'|'Average'|'Sum'|'Minimum'|'Maximum',
                'ExtendedStatistic': 'string',
                'Dimensions': [
                    {
                        'Name': 'string',
                        'Value': 'string'
                    },
                ],
                'Period': 123,
                'Unit': 'Seconds'|'Microseconds'|'Milliseconds'|'Bytes'|'Kilobytes'|'Megabytes'|'Gigabytes'|'Terabytes'|'Bits'|'Kilobits'|'Megabits'|'Gigabits'|'Terabits'|'Percent'|'Count'|'Bytes/Second'|'Kilobytes/Second'|'Megabytes/Second'|'Gigabytes/Second'|'Terabytes/Second'|'Bits/Second'|'Kilobits/Second'|'Megabits/Second'|'Gigabits/Second'|'Terabits/Second'|'Count/Second'|'None',
                'EvaluationPeriods': 123,
                'Threshold': 123.0,
                'ComparisonOperator': 'GreaterThanOrEqualToThreshold'|'GreaterThanThreshold'|'LessThanThreshold'|'LessThanOrEqualToThreshold',
                'TreatMissingData': 'string',
                'EvaluateLowSampleCountPercentile': 'string'
            },
        ]
    }
    
    
    :returns: 
    (string) --
    
    """
    pass

def disable_alarm_actions(AlarmNames=None):
    """
    Disables the actions for the specified alarms. When an alarm's actions are disabled, the alarm actions do not execute when the alarm state changes.
    See also: AWS API Documentation
    
    
    :example: response = client.disable_alarm_actions(
        AlarmNames=[
            'string',
        ]
    )
    
    
    :type AlarmNames: list
    :param AlarmNames: [REQUIRED]
            The names of the alarms.
            (string) --
            

    """
    pass

def enable_alarm_actions(AlarmNames=None):
    """
    Enables the actions for the specified alarms.
    See also: AWS API Documentation
    
    
    :example: response = client.enable_alarm_actions(
        AlarmNames=[
            'string',
        ]
    )
    
    
    :type AlarmNames: list
    :param AlarmNames: [REQUIRED]
            The names of the alarms.
            (string) --
            

    """
    pass

def generate_presigned_url(ClientMethod=None, Params=None, ExpiresIn=None, HttpMethod=None):
    """
    Generate a presigned url given a client, its method, and arguments
    
    :type ClientMethod: string
    :param ClientMethod: The client method to presign for

    :type Params: dict
    :param Params: The parameters normally passed to
            ClientMethod.

    :type ExpiresIn: int
    :param ExpiresIn: The number of seconds the presigned url is valid
            for. By default it expires in an hour (3600 seconds)

    :type HttpMethod: string
    :param HttpMethod: The http method to use on the generated url. By
            default, the http method is whatever is used in the method's model.

    """
    pass

def get_metric_statistics(Namespace=None, MetricName=None, Dimensions=None, StartTime=None, EndTime=None, Period=None, Statistics=None, ExtendedStatistics=None, Unit=None):
    """
    Gets statistics for the specified metric.
    Amazon CloudWatch retains metric data as follows:
    Note that CloudWatch started retaining 5-minute and 1-hour metric data as of 9 July 2016.
    The maximum number of data points returned from a single call is 1,440. If you request more than 1,440 data points, Amazon CloudWatch returns an error. To reduce the number of data points, you can narrow the specified time range and make multiple requests across adjacent time ranges, or you can increase the specified period. A period can be as short as one minute (60 seconds). Note that data points are not returned in chronological order.
    Amazon CloudWatch aggregates data points based on the length of the period that you specify. For example, if you request statistics with a one-hour period, Amazon CloudWatch aggregates all data points with time stamps that fall within each one-hour period. Therefore, the number of values aggregated by CloudWatch is larger than the number of data points returned.
    CloudWatch needs raw data points to calculate percentile statistics. If you publish data using a statistic set instead, you cannot retrieve percentile statistics for this data unless one of the following conditions is true:
    For a list of metrics and dimensions supported by AWS services, see the Amazon CloudWatch Metrics and Dimensions Reference in the Amazon CloudWatch User Guide .
    See also: AWS API Documentation
    
    
    :example: response = client.get_metric_statistics(
        Namespace='string',
        MetricName='string',
        Dimensions=[
            {
                'Name': 'string',
                'Value': 'string'
            },
        ],
        StartTime=datetime(2015, 1, 1),
        EndTime=datetime(2015, 1, 1),
        Period=123,
        Statistics=[
            'SampleCount'|'Average'|'Sum'|'Minimum'|'Maximum',
        ],
        ExtendedStatistics=[
            'string',
        ],
        Unit='Seconds'|'Microseconds'|'Milliseconds'|'Bytes'|'Kilobytes'|'Megabytes'|'Gigabytes'|'Terabytes'|'Bits'|'Kilobits'|'Megabits'|'Gigabits'|'Terabits'|'Percent'|'Count'|'Bytes/Second'|'Kilobytes/Second'|'Megabytes/Second'|'Gigabytes/Second'|'Terabytes/Second'|'Bits/Second'|'Kilobits/Second'|'Megabits/Second'|'Gigabits/Second'|'Terabits/Second'|'Count/Second'|'None'
    )
    
    
    :type Namespace: string
    :param Namespace: [REQUIRED]
            The namespace of the metric, with or without spaces.
            

    :type MetricName: string
    :param MetricName: [REQUIRED]
            The name of the metric, with or without spaces.
            

    :type Dimensions: list
    :param Dimensions: The dimensions. If the metric contains multiple dimensions, you must include a value for each dimension. CloudWatch treats each unique combination of dimensions as a separate metric. You can't retrieve statistics using combinations of dimensions that were not specially published. You must specify the same dimensions that were used when the metrics were created. For an example, see Dimension Combinations in the Amazon CloudWatch User Guide . For more information on specifying dimensions, see Publishing Metrics in the Amazon CloudWatch User Guide .
            (dict) --Expands the identity of a metric.
            Name (string) -- [REQUIRED]The name of the dimension.
            Value (string) -- [REQUIRED]The value representing the dimension measurement.
            
            

    :type StartTime: datetime
    :param StartTime: [REQUIRED]
            The time stamp that determines the first data point to return. Note that start times are evaluated relative to the time that CloudWatch receives the request.
            The value specified is inclusive; results include data points with the specified time stamp. The time stamp must be in ISO 8601 UTC format (for example, 2016-10-03T23:00:00Z).
            CloudWatch rounds the specified time stamp as follows:
            Start time less than 15 days ago - Round down to the nearest whole minute. For example, 12:32:34 is rounded down to 12:32:00.
            Start time between 15 and 63 days ago - Round down to the nearest 5-minute clock interval. For example, 12:32:34 is rounded down to 12:30:00.
            Start time greater than 63 days ago - Round down to the nearest 1-hour clock interval. For example, 12:32:34 is rounded down to 12:00:00.
            

    :type EndTime: datetime
    :param EndTime: [REQUIRED]
            The time stamp that determines the last data point to return.
            The value specified is exclusive; results will include data points up to the specified time stamp. The time stamp must be in ISO 8601 UTC format (for example, 2016-10-10T23:00:00Z).
            

    :type Period: integer
    :param Period: [REQUIRED]
            The granularity, in seconds, of the returned data points. A period can be as short as one minute (60 seconds) and must be a multiple of 60. The default value is 60.
            If the StartTime parameter specifies a time stamp that is greater than 15 days ago, you must specify the period as follows or no data points in that time range is returned:
            Start time between 15 and 63 days ago - Use a multiple of 300 seconds (5 minutes).
            Start time greater than 63 days ago - Use a multiple of 3600 seconds (1 hour).
            

    :type Statistics: list
    :param Statistics: The metric statistics, other than percentile. For percentile statistics, use ExtendedStatistic .
            (string) --
            

    :type ExtendedStatistics: list
    :param ExtendedStatistics: The percentile statistics. Specify values between p0.0 and p100.
            (string) --
            

    :type Unit: string
    :param Unit: The unit for a given metric. Metrics may be reported in multiple units. Not supplying a unit results in all units being returned. If the metric only ever reports one unit, specifying a unit has no effect.

    :rtype: dict
    :return: {
        'Label': 'string',
        'Datapoints': [
            {
                'Timestamp': datetime(2015, 1, 1),
                'SampleCount': 123.0,
                'Average': 123.0,
                'Sum': 123.0,
                'Minimum': 123.0,
                'Maximum': 123.0,
                'Unit': 'Seconds'|'Microseconds'|'Milliseconds'|'Bytes'|'Kilobytes'|'Megabytes'|'Gigabytes'|'Terabytes'|'Bits'|'Kilobits'|'Megabits'|'Gigabits'|'Terabits'|'Percent'|'Count'|'Bytes/Second'|'Kilobytes/Second'|'Megabytes/Second'|'Gigabytes/Second'|'Terabytes/Second'|'Bits/Second'|'Kilobits/Second'|'Megabits/Second'|'Gigabits/Second'|'Terabits/Second'|'Count/Second'|'None',
                'ExtendedStatistics': {
                    'string': 123.0
                }
            },
        ]
    }
    
    
    :returns: 
    The SampleCount of the statistic set is 1
    The Min and the Max of the statistic set are equal
    
    """
    pass

def get_paginator(operation_name=None):
    """
    Create a paginator for an operation.
    
    :type operation_name: string
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').

    :rtype: L{botocore.paginate.Paginator}
    """
    pass

def get_waiter():
    """
    
    """
    pass

def list_metrics(Namespace=None, MetricName=None, Dimensions=None, NextToken=None):
    """
    List the specified metrics. You can use the returned metrics with  GetMetricStatistics to obtain statistical data.
    Up to 500 results are returned for any one call. To retrieve additional results, use the returned token with subsequent calls.
    After you create a metric, allow up to fifteen minutes before the metric appears. Statistics about the metric, however, are available sooner using  GetMetricStatistics .
    See also: AWS API Documentation
    
    
    :example: response = client.list_metrics(
        Namespace='string',
        MetricName='string',
        Dimensions=[
            {
                'Name': 'string',
                'Value': 'string'
            },
        ],
        NextToken='string'
    )
    
    
    :type Namespace: string
    :param Namespace: The namespace to filter against.

    :type MetricName: string
    :param MetricName: The name of the metric to filter against.

    :type Dimensions: list
    :param Dimensions: The dimensions to filter against.
            (dict) --Represents filters for a dimension.
            Name (string) -- [REQUIRED]The dimension name to be matched.
            Value (string) --The value of the dimension to be matched.
            
            

    :type NextToken: string
    :param NextToken: The token returned by a previous call to indicate that there is more data available.

    :rtype: dict
    :return: {
        'Metrics': [
            {
                'Namespace': 'string',
                'MetricName': 'string',
                'Dimensions': [
                    {
                        'Name': 'string',
                        'Value': 'string'
                    },
                ]
            },
        ],
        'NextToken': 'string'
    }
    
    
    """
    pass

def put_metric_alarm(AlarmName=None, AlarmDescription=None, ActionsEnabled=None, OKActions=None, AlarmActions=None, InsufficientDataActions=None, MetricName=None, Namespace=None, Statistic=None, ExtendedStatistic=None, Dimensions=None, Period=None, Unit=None, EvaluationPeriods=None, Threshold=None, ComparisonOperator=None, TreatMissingData=None, EvaluateLowSampleCountPercentile=None):
    """
    Creates or updates an alarm and associates it with the specified metric. Optionally, this operation can associate one or more Amazon SNS resources with the alarm.
    When this operation creates an alarm, the alarm state is immediately set to INSUFFICIENT_DATA . The alarm is evaluated and its state is set appropriately. Any actions associated with the state are then executed.
    When you update an existing alarm, its state is left unchanged, but the update completely overwrites the previous configuration of the alarm.
    If you are an AWS Identity and Access Management (IAM) user, you must have Amazon EC2 permissions for some operations:
    If you have read/write permissions for Amazon CloudWatch but not for Amazon EC2, you can still create an alarm, but the stop or terminate actions won't be performed. However, if you are later granted the required permissions, the alarm actions that you created earlier will be performed.
    If you are using an IAM role (for example, an Amazon EC2 instance profile), you cannot stop or terminate the instance using alarm actions. However, you can still see the alarm state and perform any other actions such as Amazon SNS notifications or Auto Scaling policies.
    If you are using temporary security credentials granted using the AWS Security Token Service (AWS STS), you cannot stop or terminate an Amazon EC2 instance using alarm actions.
    Note that you must create at least one stop, terminate, or reboot alarm using the Amazon EC2 or CloudWatch console to create the EC2ActionsAccess IAM role. After this IAM role is created, you can create stop, terminate, or reboot alarms using a command-line interface or an API.
    See also: AWS API Documentation
    
    
    :example: response = client.put_metric_alarm(
        AlarmName='string',
        AlarmDescription='string',
        ActionsEnabled=True|False,
        OKActions=[
            'string',
        ],
        AlarmActions=[
            'string',
        ],
        InsufficientDataActions=[
            'string',
        ],
        MetricName='string',
        Namespace='string',
        Statistic='SampleCount'|'Average'|'Sum'|'Minimum'|'Maximum',
        ExtendedStatistic='string',
        Dimensions=[
            {
                'Name': 'string',
                'Value': 'string'
            },
        ],
        Period=123,
        Unit='Seconds'|'Microseconds'|'Milliseconds'|'Bytes'|'Kilobytes'|'Megabytes'|'Gigabytes'|'Terabytes'|'Bits'|'Kilobits'|'Megabits'|'Gigabits'|'Terabits'|'Percent'|'Count'|'Bytes/Second'|'Kilobytes/Second'|'Megabytes/Second'|'Gigabytes/Second'|'Terabytes/Second'|'Bits/Second'|'Kilobits/Second'|'Megabits/Second'|'Gigabits/Second'|'Terabits/Second'|'Count/Second'|'None',
        EvaluationPeriods=123,
        Threshold=123.0,
        ComparisonOperator='GreaterThanOrEqualToThreshold'|'GreaterThanThreshold'|'LessThanThreshold'|'LessThanOrEqualToThreshold',
        TreatMissingData='string',
        EvaluateLowSampleCountPercentile='string'
    )
    
    
    :type AlarmName: string
    :param AlarmName: [REQUIRED]
            The name for the alarm. This name must be unique within the AWS account.
            

    :type AlarmDescription: string
    :param AlarmDescription: The description for the alarm.

    :type ActionsEnabled: boolean
    :param ActionsEnabled: Indicates whether actions should be executed during any changes to the alarm state.

    :type OKActions: list
    :param OKActions: The actions to execute when this alarm transitions to an OK state from any other state. Each action is specified as an Amazon Resource Name (ARN).
            Valid Values: arn:aws:automate:region :ec2:stop | arn:aws:automate:region :ec2:terminate | arn:aws:automate:region :ec2:recover
            Valid Values (for use with IAM roles): arn:aws:swf:us-east-1:{customer-account }:action/actions/AWS_EC2.InstanceId.Stop/1.0 | arn:aws:swf:us-east-1:{customer-account }:action/actions/AWS_EC2.InstanceId.Terminate/1.0 | arn:aws:swf:us-east-1:{customer-account }:action/actions/AWS_EC2.InstanceId.Reboot/1.0
            (string) --
            

    :type AlarmActions: list
    :param AlarmActions: The actions to execute when this alarm transitions to the ALARM state from any other state. Each action is specified as an Amazon Resource Name (ARN).
            Valid Values: arn:aws:automate:region :ec2:stop | arn:aws:automate:region :ec2:terminate | arn:aws:automate:region :ec2:recover
            Valid Values (for use with IAM roles): arn:aws:swf:us-east-1:{customer-account }:action/actions/AWS_EC2.InstanceId.Stop/1.0 | arn:aws:swf:us-east-1:{customer-account }:action/actions/AWS_EC2.InstanceId.Terminate/1.0 | arn:aws:swf:us-east-1:{customer-account }:action/actions/AWS_EC2.InstanceId.Reboot/1.0
            (string) --
            

    :type InsufficientDataActions: list
    :param InsufficientDataActions: The actions to execute when this alarm transitions to the INSUFFICIENT_DATA state from any other state. Each action is specified as an Amazon Resource Name (ARN).
            Valid Values: arn:aws:automate:region :ec2:stop | arn:aws:automate:region :ec2:terminate | arn:aws:automate:region :ec2:recover
            Valid Values (for use with IAM roles): arn:aws:swf:us-east-1:{customer-account }:action/actions/AWS_EC2.InstanceId.Stop/1.0 | arn:aws:swf:us-east-1:{customer-account }:action/actions/AWS_EC2.InstanceId.Terminate/1.0 | arn:aws:swf:us-east-1:{customer-account }:action/actions/AWS_EC2.InstanceId.Reboot/1.0
            (string) --
            

    :type MetricName: string
    :param MetricName: [REQUIRED]
            The name for the metric associated with the alarm.
            

    :type Namespace: string
    :param Namespace: [REQUIRED]
            The namespace for the metric associated with the alarm.
            

    :type Statistic: string
    :param Statistic: The statistic for the metric associated with the alarm, other than percentile. For percentile statistics, use ExtendedStatistic .

    :type ExtendedStatistic: string
    :param ExtendedStatistic: The percentile statistic for the metric associated with the alarm. Specify a value between p0.0 and p100.

    :type Dimensions: list
    :param Dimensions: The dimensions for the metric associated with the alarm.
            (dict) --Expands the identity of a metric.
            Name (string) -- [REQUIRED]The name of the dimension.
            Value (string) -- [REQUIRED]The value representing the dimension measurement.
            
            

    :type Period: integer
    :param Period: [REQUIRED]
            The period, in seconds, over which the specified statistic is applied.
            

    :type Unit: string
    :param Unit: The unit of measure for the statistic. For example, the units for the Amazon EC2 NetworkIn metric are Bytes because NetworkIn tracks the number of bytes that an instance receives on all network interfaces. You can also specify a unit when you create a custom metric. Units help provide conceptual meaning to your data. Metric data points that specify a unit of measure, such as Percent, are aggregated separately.
            If you specify a unit, you must use a unit that is appropriate for the metric. Otherwise, the Amazon CloudWatch alarm can get stuck in the INSUFFICIENT DATA state.
            

    :type EvaluationPeriods: integer
    :param EvaluationPeriods: [REQUIRED]
            The number of periods over which data is compared to the specified threshold.
            

    :type Threshold: float
    :param Threshold: [REQUIRED]
            The value against which the specified statistic is compared.
            

    :type ComparisonOperator: string
    :param ComparisonOperator: [REQUIRED]
            The arithmetic operation to use when comparing the specified statistic and threshold. The specified statistic value is used as the first operand.
            

    :type TreatMissingData: string
    :param TreatMissingData: Sets how this alarm is to handle missing data points. If TreatMissingData is omitted, the default behavior of missing is used. For more information, see Configuring How CloudWatch Alarms Treats Missing Data .
            Valid Values: breaching | notBreaching | ignore | missing
            

    :type EvaluateLowSampleCountPercentile: string
    :param EvaluateLowSampleCountPercentile: Used only for alarms based on percentiles. If you specify ignore , the alarm state will not change during periods with too few data points to be statistically significant. If you specify evaluate or omit this parameter, the alarm will always be evaluated and possibly change state no matter how many data points are available. For more information, see Percentile-Based CloudWatch Alarms and Low Data Samples .
            Valid Values: evaluate | ignore
            

    :returns: 
    AlarmName (string) -- [REQUIRED]
    The name for the alarm. This name must be unique within the AWS account.
    
    AlarmDescription (string) -- The description for the alarm.
    ActionsEnabled (boolean) -- Indicates whether actions should be executed during any changes to the alarm state.
    OKActions (list) -- The actions to execute when this alarm transitions to an OK state from any other state. Each action is specified as an Amazon Resource Name (ARN).
    Valid Values: arn:aws:automate:region :ec2:stop | arn:aws:automate:region :ec2:terminate | arn:aws:automate:region :ec2:recover
    Valid Values (for use with IAM roles): arn:aws:swf:us-east-1:{customer-account }:action/actions/AWS_EC2.InstanceId.Stop/1.0 | arn:aws:swf:us-east-1:{customer-account }:action/actions/AWS_EC2.InstanceId.Terminate/1.0 | arn:aws:swf:us-east-1:{customer-account }:action/actions/AWS_EC2.InstanceId.Reboot/1.0
    
    (string) --
    
    
    AlarmActions (list) -- The actions to execute when this alarm transitions to the ALARM state from any other state. Each action is specified as an Amazon Resource Name (ARN).
    Valid Values: arn:aws:automate:region :ec2:stop | arn:aws:automate:region :ec2:terminate | arn:aws:automate:region :ec2:recover
    Valid Values (for use with IAM roles): arn:aws:swf:us-east-1:{customer-account }:action/actions/AWS_EC2.InstanceId.Stop/1.0 | arn:aws:swf:us-east-1:{customer-account }:action/actions/AWS_EC2.InstanceId.Terminate/1.0 | arn:aws:swf:us-east-1:{customer-account }:action/actions/AWS_EC2.InstanceId.Reboot/1.0
    
    (string) --
    
    
    InsufficientDataActions (list) -- The actions to execute when this alarm transitions to the INSUFFICIENT_DATA state from any other state. Each action is specified as an Amazon Resource Name (ARN).
    Valid Values: arn:aws:automate:region :ec2:stop | arn:aws:automate:region :ec2:terminate | arn:aws:automate:region :ec2:recover
    Valid Values (for use with IAM roles): arn:aws:swf:us-east-1:{customer-account }:action/actions/AWS_EC2.InstanceId.Stop/1.0 | arn:aws:swf:us-east-1:{customer-account }:action/actions/AWS_EC2.InstanceId.Terminate/1.0 | arn:aws:swf:us-east-1:{customer-account }:action/actions/AWS_EC2.InstanceId.Reboot/1.0
    
    (string) --
    
    
    MetricName (string) -- [REQUIRED]
    The name for the metric associated with the alarm.
    
    Namespace (string) -- [REQUIRED]
    The namespace for the metric associated with the alarm.
    
    Statistic (string) -- The statistic for the metric associated with the alarm, other than percentile. For percentile statistics, use ExtendedStatistic .
    ExtendedStatistic (string) -- The percentile statistic for the metric associated with the alarm. Specify a value between p0.0 and p100.
    Dimensions (list) -- The dimensions for the metric associated with the alarm.
    
    (dict) --Expands the identity of a metric.
    
    Name (string) -- [REQUIRED]The name of the dimension.
    
    Value (string) -- [REQUIRED]The value representing the dimension measurement.
    
    
    
    
    
    Period (integer) -- [REQUIRED]
    The period, in seconds, over which the specified statistic is applied.
    
    Unit (string) -- The unit of measure for the statistic. For example, the units for the Amazon EC2 NetworkIn metric are Bytes because NetworkIn tracks the number of bytes that an instance receives on all network interfaces. You can also specify a unit when you create a custom metric. Units help provide conceptual meaning to your data. Metric data points that specify a unit of measure, such as Percent, are aggregated separately.
    If you specify a unit, you must use a unit that is appropriate for the metric. Otherwise, the Amazon CloudWatch alarm can get stuck in the INSUFFICIENT DATA state.
    
    EvaluationPeriods (integer) -- [REQUIRED]
    The number of periods over which data is compared to the specified threshold.
    
    Threshold (float) -- [REQUIRED]
    The value against which the specified statistic is compared.
    
    ComparisonOperator (string) -- [REQUIRED]
    The arithmetic operation to use when comparing the specified statistic and threshold. The specified statistic value is used as the first operand.
    
    TreatMissingData (string) -- Sets how this alarm is to handle missing data points. If TreatMissingData is omitted, the default behavior of missing is used. For more information, see Configuring How CloudWatch Alarms Treats Missing Data .
    Valid Values: breaching | notBreaching | ignore | missing
    
    EvaluateLowSampleCountPercentile (string) -- Used only for alarms based on percentiles. If you specify ignore , the alarm state will not change during periods with too few data points to be statistically significant. If you specify evaluate or omit this parameter, the alarm will always be evaluated and possibly change state no matter how many data points are available. For more information, see Percentile-Based CloudWatch Alarms and Low Data Samples .
    Valid Values: evaluate | ignore
    
    
    """
    pass

def put_metric_data(Namespace=None, MetricData=None):
    """
    Publishes metric data points to Amazon CloudWatch. Amazon CloudWatch associates the data points with the specified metric. If the specified metric does not exist, Amazon CloudWatch creates the metric. When Amazon CloudWatch creates a metric, it can take up to fifteen minutes for the metric to appear in calls to  ListMetrics .
    Each PutMetricData request is limited to 40 KB in size for HTTP POST requests.
    Although the Value parameter accepts numbers of type Double , Amazon CloudWatch rejects values that are either too small or too large. Values must be in the range of 8.515920e-109 to 1.174271e+108 (Base 10) or 2e-360 to 2e360 (Base 2). In addition, special values (e.g., NaN, +Infinity, -Infinity) are not supported.
    You can use up to 10 dimensions per metric to further clarify what data the metric collects. For more information on specifying dimensions, see Publishing Metrics in the Amazon CloudWatch User Guide .
    Data points with time stamps from 24 hours ago or longer can take at least 48 hours to become available for  GetMetricStatistics from the time they are submitted.
    CloudWatch needs raw data points to calculate percentile statistics. If you publish data using a statistic set instead, you cannot retrieve percentile statistics for this data unless one of the following conditions is true:
    See also: AWS API Documentation
    
    
    :example: response = client.put_metric_data(
        Namespace='string',
        MetricData=[
            {
                'MetricName': 'string',
                'Dimensions': [
                    {
                        'Name': 'string',
                        'Value': 'string'
                    },
                ],
                'Timestamp': datetime(2015, 1, 1),
                'Value': 123.0,
                'StatisticValues': {
                    'SampleCount': 123.0,
                    'Sum': 123.0,
                    'Minimum': 123.0,
                    'Maximum': 123.0
                },
                'Unit': 'Seconds'|'Microseconds'|'Milliseconds'|'Bytes'|'Kilobytes'|'Megabytes'|'Gigabytes'|'Terabytes'|'Bits'|'Kilobits'|'Megabits'|'Gigabits'|'Terabits'|'Percent'|'Count'|'Bytes/Second'|'Kilobytes/Second'|'Megabytes/Second'|'Gigabytes/Second'|'Terabytes/Second'|'Bits/Second'|'Kilobits/Second'|'Megabits/Second'|'Gigabits/Second'|'Terabits/Second'|'Count/Second'|'None'
            },
        ]
    )
    
    
    :type Namespace: string
    :param Namespace: [REQUIRED]
            The namespace for the metric data.
            You cannot specify a namespace that begins with 'AWS/'. Namespaces that begin with 'AWS/' are reserved for use by Amazon Web Services products.
            

    :type MetricData: list
    :param MetricData: [REQUIRED]
            The data for the metric.
            (dict) --Encapsulates the information sent to either create a metric or add new values to be aggregated into an existing metric.
            MetricName (string) -- [REQUIRED]The name of the metric.
            Dimensions (list) --The dimensions associated with the metric.
            (dict) --Expands the identity of a metric.
            Name (string) -- [REQUIRED]The name of the dimension.
            Value (string) -- [REQUIRED]The value representing the dimension measurement.
            
            Timestamp (datetime) --The time the metric data was received, expressed as the number of milliseconds since Jan 1, 1970 00:00:00 UTC.
            Value (float) --The value for the metric.
            Although the parameter accepts numbers of type Double, Amazon CloudWatch rejects values that are either too small or too large. Values must be in the range of 8.515920e-109 to 1.174271e+108 (Base 10) or 2e-360 to 2e360 (Base 2). In addition, special values (for example, NaN, +Infinity, -Infinity) are not supported.
            StatisticValues (dict) --The statistical values for the metric.
            SampleCount (float) -- [REQUIRED]The number of samples used for the statistic set.
            Sum (float) -- [REQUIRED]The sum of values for the sample set.
            Minimum (float) -- [REQUIRED]The minimum value of the sample set.
            Maximum (float) -- [REQUIRED]The maximum value of the sample set.
            Unit (string) --The unit of the metric.
            
            

    :returns: 
    Namespace (string) -- [REQUIRED]
    The namespace for the metric data.
    You cannot specify a namespace that begins with "AWS/". Namespaces that begin with "AWS/" are reserved for use by Amazon Web Services products.
    
    MetricData (list) -- [REQUIRED]
    The data for the metric.
    
    (dict) --Encapsulates the information sent to either create a metric or add new values to be aggregated into an existing metric.
    
    MetricName (string) -- [REQUIRED]The name of the metric.
    
    Dimensions (list) --The dimensions associated with the metric.
    
    (dict) --Expands the identity of a metric.
    
    Name (string) -- [REQUIRED]The name of the dimension.
    
    Value (string) -- [REQUIRED]The value representing the dimension measurement.
    
    
    
    
    
    Timestamp (datetime) --The time the metric data was received, expressed as the number of milliseconds since Jan 1, 1970 00:00:00 UTC.
    
    Value (float) --The value for the metric.
    Although the parameter accepts numbers of type Double, Amazon CloudWatch rejects values that are either too small or too large. Values must be in the range of 8.515920e-109 to 1.174271e+108 (Base 10) or 2e-360 to 2e360 (Base 2). In addition, special values (for example, NaN, +Infinity, -Infinity) are not supported.
    
    StatisticValues (dict) --The statistical values for the metric.
    
    SampleCount (float) -- [REQUIRED]The number of samples used for the statistic set.
    
    Sum (float) -- [REQUIRED]The sum of values for the sample set.
    
    Minimum (float) -- [REQUIRED]The minimum value of the sample set.
    
    Maximum (float) -- [REQUIRED]The maximum value of the sample set.
    
    
    
    Unit (string) --The unit of the metric.
    
    
    
    
    
    
    """
    pass

def set_alarm_state(AlarmName=None, StateValue=None, StateReason=None, StateReasonData=None):
    """
    Temporarily sets the state of an alarm for testing purposes. When the updated state differs from the previous value, the action configured for the appropriate state is invoked. For example, if your alarm is configured to send an Amazon SNS message when an alarm is triggered, temporarily changing the alarm state to ALARM sends an Amazon SNS message. The alarm returns to its actual state (often within seconds). Because the alarm state change happens very quickly, it is typically only visible in the alarm's History tab in the Amazon CloudWatch console or through  DescribeAlarmHistory .
    See also: AWS API Documentation
    
    
    :example: response = client.set_alarm_state(
        AlarmName='string',
        StateValue='OK'|'ALARM'|'INSUFFICIENT_DATA',
        StateReason='string',
        StateReasonData='string'
    )
    
    
    :type AlarmName: string
    :param AlarmName: [REQUIRED]
            The name for the alarm. This name must be unique within the AWS account. The maximum length is 255 characters.
            

    :type StateValue: string
    :param StateValue: [REQUIRED]
            The value of the state.
            

    :type StateReason: string
    :param StateReason: [REQUIRED]
            The reason that this alarm is set to this specific state, in text format.
            

    :type StateReasonData: string
    :param StateReasonData: The reason that this alarm is set to this specific state, in JSON format.

    """
    pass

